@@ -5,7 +5,7 @@ import numpy as np
 from tlz import concat, get, partial
 from tlz.curried import map
 
-from dask.array import chunk, numpy_compat
+from dask.array import chunk
 from dask.array.core import Array, concatenate, map_blocks, unify_chunks
 from dask.array.creation import empty_like, full_like
 from dask.base import tokenize
@@ -778,7 +778,7 @@ def coerce_boundary(ndim, boundary):
     return boundary
 
 
-@derived_from(numpy_compat)
+@derived_from(np.lib.stride_tricks)
 def sliding_window_view(x, window_shape, axis=None):
     from numpy.core.numeric import normalize_axis_tuple
 
@@ -826,7 +826,7 @@ def sliding_window_view(x, window_shape, axis=None):
     )
 
     return map_overlap(
-        numpy_compat.sliding_window_view,
+        np.lib.stride_tricks.sliding_window_view,
         x,
         depth=tuple((0, d) for d in depths),  # Overlap on +ve side only
         boundary="none",
