@@ -1889,7 +1889,6 @@ def setitem_array(out_name, array, indices, value):
     dsk = {}
     out_name = (out_name,)
     for in_key, locations in zip(in_keys, array_locations):
-
         # Now loop round each block dimension.
         #
         # If the block overlaps the indices then set the following
@@ -1921,10 +1920,7 @@ def setitem_array(out_name, array, indices, value):
         # Note which dimension, if any, has 1-d integer array index
         dim_1d_int_index = None
 
-        for dim, (index, full_size, (loc0, loc1)) in enumerate(
-            zip(indices, array_shape, locations)
-        ):
-
+        for dim, (index, (loc0, loc1)) in enumerate(zip(indices, locations)):
             integer_index = isinstance(index, int)
             if isinstance(index, slice):
                 # Index is a slice
