@@ -40,7 +40,6 @@ def test_arr_like(
 ):
     backend_lib = pytest.importorskip(backend)
     with dask.config.set({"array.backend": backend}):
-
         np_func = getattr(backend_lib, funcname)
         da_func = getattr(da, funcname)
         shape = cast_shape(shape)
@@ -755,6 +754,7 @@ def test_pad_0_width(shape, chunks, pad_width, mode, kwargs):
     [
         ((10,), (3,), 1, "constant", {}),
         ((10,), (3,), 2, "constant", {"constant_values": -1}),
+        ((10,), (3,), 2, "constant", {"constant_values": np.array(-1)}),
         ((10,), (3,), ((2, 3)), "constant", {"constant_values": (-1, -2)}),
         (
             (10, 11),
@@ -796,6 +796,49 @@ def test_pad(shape, chunks, pad_width, mode, kwargs):
         assert_eq(np_r, da_r)
 
 
+@pytest.mark.parametrize(
+    ["np_a", "pad_value"],
+    (
+        (np.arange(4, dtype="int64"), np.int64(1)),
+        (np.arange(4, dtype="float64"), np.float64(0)),
+        (
+            np.array(
+                ["2000-01-01", "2000-01-02", "2000-01-03", "2000-01-04"],
+                dtype="datetime64[ns]",
+            ),
+            np.datetime64("1972-01-01"),
+        ),
+        (np.array([True, False, True, True], dtype=np.bool_), np.bool_(False)),
+        (np.array(["ab", "bc", "de", "ef"], dtype=np.str_), np.str_("00")),
+        (np.arange(4, dtype="int64"), np.array(1, dtype="int64")),
+        (np.arange(4, dtype="float64"), np.array(0, dtype="float64")),
+        (
+            np.array(
+                ["2000-01-01", "2000-01-02", "2000-01-03", "2000-01-04"],
+                dtype="datetime64[ns]",
+            ),
+            np.array("1972-01-01", dtype="datetime64[ns]"),
+        ),
+        (
+            np.array([True, False, True, True], dtype=np.bool_),
+            np.array(False, dtype=np.bool_),
+        ),
+        (
+            np.array(["ab", "bc", "de", "ef"], dtype=np.str_),
+            np.array("00", dtype=np.str_),
+        ),
+    ),
+)
+def test_pad_constant_values(np_a, pad_value):
+    pad_width = (1, 1)
+    da_a = da.from_array(np_a, chunks=(2,))
+
+    np_r = np.pad(np_a, pad_width, mode="constant", constant_values=pad_value)
+    da_r = da.pad(da_a, pad_width, mode="constant", constant_values=pad_value)
+
+    assert_eq(np_r, da_r)
+
+
 @pytest.mark.parametrize("dtype", [np.uint8, np.int16, np.float32, bool])
 @pytest.mark.parametrize(
     "pad_widths", [2, (2,), (2, 3), ((2, 3),), ((3, 1), (0, 0), (2, 0))]
@@ -892,3 +935,49 @@ def test_diagonal_zero_chunks():
     assert_eq(d + d, 2 * expected)
     A = d + x
     assert_eq(A, np.full((8, 8), 2.0))
+
+
+@pytest.mark.parametrize("fn", ["zeros_like", "ones_like"])
+@pytest.mark.parametrize("shape_chunks", [((50, 4), (10, 2)), ((50,), (10,))])
+@pytest.mark.parametrize("dtype", ["u4", np.float32, None, np.int64])
+def test_nan_zeros_ones_like(fn, shape_chunks, dtype):
+    dafn = getattr(da, fn)
+    npfn = getattr(np, fn)
+    shape, chunks = shape_chunks
+    x1 = da.random.standard_normal(size=shape, chunks=chunks)
+    y1 = x1[x1 < 0.5]
+    x2 = x1.compute()
+    y2 = x2[x2 < 0.5]
+    assert_eq(
+        dafn(y1, dtype=dtype),
+        npfn(y2, dtype=dtype),
+    )
+
+
+@pytest.mark.parametrize("shape_chunks", [((50, 4), (10, 2)), ((50,), (10,))])
+@pytest.mark.parametrize("dtype", ["u4", np.float32, None, np.int64])
+def test_nan_empty_like(shape_chunks, dtype):
+    shape, chunks = shape_chunks
+    x1 = da.random.standard_normal(size=shape, chunks=chunks)
+    y1 = x1[x1 < 0.5]
+    x2 = x1.compute()
+    y2 = x2[x2 < 0.5]
+    a_da = da.empty_like(y1, dtype=dtype).compute()
+    a_np = np.empty_like(y2, dtype=dtype)
+    assert a_da.shape == a_np.shape
+    assert a_da.dtype == a_np.dtype
+
+
+@pytest.mark.parametrize("val", [0, 0.0, 99, -1])
+@pytest.mark.parametrize("shape_chunks", [((50, 4), (10, 2)), ((50,), (10,))])
+@pytest.mark.parametrize("dtype", ["u4", np.float32, None, np.int64])
+def test_nan_full_like(val, shape_chunks, dtype):
+    shape, chunks = shape_chunks
+    x1 = da.random.standard_normal(size=shape, chunks=chunks)
+    y1 = x1[x1 < 0.5]
+    x2 = x1.compute()
+    y2 = x2[x2 < 0.5]
+    assert_eq(
+        da.full_like(y1, val, dtype=dtype),
+        np.full_like(y2, val, dtype=dtype),
+    )
