@@ -4,13 +4,11 @@ import pytest
 pytestmark = pytest.mark.gpu
 
 import dask.array as da
-from dask.array.numpy_compat import _numpy_120
 from dask.array.utils import assert_eq, same_keys
 
 cupy = pytest.importorskip("cupy")
 
 
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 def test_percentile():
     d = da.from_array(cupy.ones((16,)), chunks=(4,))
     qs = np.array([0, 50, 100])
@@ -34,14 +32,12 @@ def test_percentile():
     reason="Non-deterministic tokenize(cupy.array(...)), "
     "see https://github.com/dask/dask/issues/6718"
 )
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 def test_percentile_tokenize():
     d = da.from_array(cupy.ones((16,)), chunks=(4,))
     qs = np.array([0, 50, 100])
     assert same_keys(da.percentile(d, qs), da.percentile(d, qs))
 
 
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 def test_percentiles_with_empty_arrays():
     x = da.from_array(cupy.ones(10), chunks=((5, 0, 5),))
     result = da.percentile(x, [10, 50, 90], method="midpoint")
@@ -50,7 +46,6 @@ def test_percentiles_with_empty_arrays():
     assert_eq(result, np.array([1, 1, 1], dtype=x.dtype), check_type=False)
 
 
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 def test_percentiles_with_empty_q():
     x = da.from_array(cupy.ones(10), chunks=((5, 0, 5),))
     result = da.percentile(x, [], method="midpoint")
@@ -59,7 +54,6 @@ def test_percentiles_with_empty_q():
     assert_eq(result, np.array([], dtype=x.dtype), check_type=False)
 
 
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 @pytest.mark.parametrize("q", [5, 5.0, np.int64(5), np.float64(5)])
 def test_percentiles_with_scaler_percentile(q):
     # Regression test to ensure da.percentile works with scalar percentiles
@@ -71,10 +65,9 @@ def test_percentiles_with_scaler_percentile(q):
     assert_eq(result, np.array([1], dtype=d.dtype), check_type=False)
 
 
-@pytest.mark.skipif(not _numpy_120, reason="NEP-35 is not available")
 def test_percentiles_with_unknown_chunk_sizes():
-    rs = da.random.RandomState(RandomState=cupy.random.RandomState)
-    x = rs.random(1000, chunks=(100,))
+    rng = da.random.default_rng(cupy.random.default_rng())
+    x = rng.random(1000, chunks=(100,))
     x._chunks = ((np.nan,) * 10,)
 
     result = da.percentile(x, 50, method="midpoint").compute()
