@@ -502,7 +502,7 @@ def test_map_overlap_multiarray_variadic():
     ),
 )
 def test_map_overlap_trim_using_drop_axis_and_different_depths(drop_axis):
-    x = da.random.standard_normal((5, 10, 8), chunks=(2, 5, 4))
+    x = da.random.default_rng().standard_normal((5, 10, 8), chunks=(2, 5, 4))
 
     def _mean(x):
         return x.mean(axis=drop_axis)
@@ -667,8 +667,8 @@ def test_overlap_small():
 
 
 def test_no_shared_keys_with_different_depths():
-    da.random.seed(0)
-    a = da.random.random((9, 9), chunks=(3, 3))
+    rng = da.random.default_rng(0)
+    a = rng.random((9, 9), chunks=(3, 3))
 
     def check(x):
         assert x.shape == (3, 3)
@@ -749,7 +749,7 @@ def test_map_overlap_rechunks_array_if_needed():
 
 def test_map_overlap_rechunks_array_along_multiple_dims_if_needed():
     # https://github.com/dask/dask/issues/6688
-    rand = da.random.random((860, 1024, 1024), chunks=(1, 1024, 1024))
+    rand = da.random.default_rng().random((860, 1024, 1024), chunks=(1, 1024, 1024))
     filtered = rand.map_overlap(
         lambda arr: arr,
         depth=(2, 2, 2),
@@ -801,11 +801,11 @@ def test_ensure_minimum_chunksize_raises_error():
     ],
 )
 def test_sliding_window_view(shape, chunks, window_shape, axis):
-    from dask.array.numpy_compat import sliding_window_view as np_sliding_window_view
-
     arr = da.from_array(np.arange(np.prod(shape)).reshape(shape), chunks=chunks)
     actual = sliding_window_view(arr, window_shape, axis)
-    expected = np_sliding_window_view(arr.compute(), window_shape, axis)
+    expected = np.lib.stride_tricks.sliding_window_view(
+        arr.compute(), window_shape, axis
+    )
     assert_eq(expected, actual)
 
 
