@@ -121,7 +121,7 @@ def test_intersect_2():
 
 def test_rechunk_1d():
     """Try rechunking a random 1d matrix"""
-    a = np.random.uniform(0, 1, 30)
+    a = np.random.default_rng().uniform(0, 1, 30)
     x = da.from_array(a, chunks=((10,) * 3,))
     new = ((5,) * 6,)
     x2 = rechunk(x, chunks=new)
@@ -131,7 +131,7 @@ def test_rechunk_1d():
 
 def test_rechunk_2d():
     """Try rechunking a random 2d matrix"""
-    a = np.random.uniform(0, 1, 300).reshape((10, 30))
+    a = np.random.default_rng().uniform(0, 1, 300).reshape((10, 30))
     x = da.from_array(a, chunks=((1, 2, 3, 4), (5,) * 6))
     new = ((5, 5), (15,) * 2)
     x2 = rechunk(x, chunks=new)
@@ -142,7 +142,7 @@ def test_rechunk_2d():
 def test_rechunk_4d():
     """Try rechunking a random 4d matrix"""
     old = ((5, 5),) * 4
-    a = np.random.uniform(0, 1, 10000).reshape((10,) * 4)
+    a = np.random.default_rng().uniform(0, 1, 10000).reshape((10,) * 4)
     x = da.from_array(a, chunks=old)
     new = ((10,),) * 4
     x2 = rechunk(x, chunks=new)
@@ -151,7 +151,7 @@ def test_rechunk_4d():
 
 
 def test_rechunk_expand():
-    a = np.random.uniform(0, 1, 100).reshape((10, 10))
+    a = np.random.default_rng().uniform(0, 1, 100).reshape((10, 10))
     x = da.from_array(a, chunks=(5, 5))
     y = x.rechunk(chunks=((3, 3, 3, 1), (3, 3, 3, 1)))
     assert np.all(y.compute() == a)
@@ -159,7 +159,7 @@ def test_rechunk_expand():
 
 def test_rechunk_expand2():
     (a, b) = (3, 2)
-    orig = np.random.uniform(0, 1, a**b).reshape((a,) * b)
+    orig = np.random.default_rng().uniform(0, 1, a**b).reshape((a,) * b)
     for off, off2 in product(range(1, a - 1), range(1, a - 1)):
         old = ((a - off, off),) * b
         x = da.from_array(orig, chunks=old)
@@ -175,7 +175,7 @@ def test_rechunk_method():
     """Test rechunking can be done as a method of dask array."""
     old = ((5, 2, 3),) * 4
     new = ((3, 3, 3, 1),) * 4
-    a = np.random.uniform(0, 1, 10000).reshape((10,) * 4)
+    a = np.random.default_rng().uniform(0, 1, 10000).reshape((10,) * 4)
     x = da.from_array(a, chunks=old)
     x2 = x.rechunk(chunks=new)
     assert x2.chunks == new
@@ -187,7 +187,7 @@ def test_rechunk_blockshape():
     new_shape, new_chunks = (10, 10), (4, 3)
     new_blockdims = normalize_chunks(new_chunks, new_shape)
     old_chunks = ((4, 4, 2), (3, 3, 3, 1))
-    a = np.random.uniform(0, 1, 100).reshape((10, 10))
+    a = np.random.default_rng().uniform(0, 1, 100).reshape((10, 10))
     x = da.from_array(a, chunks=old_chunks)
     check1 = rechunk(x, chunks=new_chunks)
     assert check1.chunks == new_blockdims
@@ -212,6 +212,10 @@ def test_rechunk_with_dict():
     y = x.rechunk(chunks={0: -1})
     assert y.chunks == ((24,), (8, 8, 8))
 
+    x = da.ones((24, 24), chunks=(4, 8))
+    y = x.rechunk(chunks={0: None, 1: "auto"})
+    assert y.chunks == ((4, 4, 4, 4, 4, 4), (24,))
+
 
 def test_rechunk_with_empty_input():
     x = da.ones((24, 24), chunks=(4, 8))
@@ -222,6 +226,10 @@ def test_rechunk_with_empty_input():
 def test_rechunk_with_null_dimensions():
     x = da.from_array(np.ones((24, 24)), chunks=(4, 8))
     assert x.rechunk(chunks=(None, 4)).chunks == da.ones((24, 24), chunks=(4, 4)).chunks
+    assert (
+        x.rechunk(chunks={0: None, 1: 4}).chunks
+        == da.ones((24, 24), chunks=(4, 4)).chunks
+    )
 
 
 def test_rechunk_with_integer():
@@ -274,6 +282,28 @@ def test_rechunk_same():
     assert x is y
 
 
+def test_rechunk_same_unknown():
+    dd = pytest.importorskip("dask.dataframe")
+    x = da.ones(shape=(10, 10), chunks=(5, 10))
+    y = dd.from_array(x).values
+    new_chunks = ((np.nan, np.nan), (10,))
+    assert y.chunks == new_chunks
+    result = y.rechunk(new_chunks)
+    assert y is result
+
+
+def test_rechunk_same_unknown_floats():
+    """Similar to test_rechunk_same_unknown but testing the behavior if
+    ``float("nan")`` is used instead of the recommended ``np.nan``
+    """
+    dd = pytest.importorskip("dask.dataframe")
+    x = da.ones(shape=(10, 10), chunks=(5, 10))
+    y = dd.from_array(x).values
+    new_chunks = ((float("nan"), float("nan")), (10,))
+    result = y.rechunk(new_chunks)
+    assert y is result
+
+
 def test_rechunk_with_zero_placeholders():
     x = da.ones((24, 24), chunks=((12, 12), (24, 0)))
     y = da.ones((24, 24), chunks=((12, 12), (12, 12)))
@@ -289,7 +319,7 @@ def test_rechunk_minus_one():
 
 
 def test_rechunk_intermediates():
-    x = da.random.normal(10, 0.1, (10, 10), chunks=(10, 1))
+    x = da.random.default_rng().normal(10, 0.1, (10, 10), chunks=(10, 1))
     y = x.rechunk((1, 10))
     assert len(y.dask) > 30
 
@@ -360,8 +390,8 @@ def _assert_steps(steps, expected):
 def test_plan_rechunk():
     c = (20,) * 2  # coarse
     f = (2,) * 20  # fine
-    nc = (float("nan"),) * 2  # nan-coarse
-    nf = (float("nan"),) * 20  # nan-fine
+    nc = (np.nan,) * 2  # nan-coarse
+    nf = (np.nan,) * 20  # nan-fine
 
     # Trivial cases
     steps = _plan((), ())
@@ -483,7 +513,7 @@ def test_plan_rechunk_asymmetric():
 
 def test_rechunk_warning():
     N = 20
-    x = da.random.normal(size=(N, N, 100), chunks=(1, N, 100))
+    x = da.random.default_rng().normal(size=(N, N, 100), chunks=(1, N, 100))
     with warnings.catch_warnings(record=True) as w:
         x = x.rechunk((N, 1, 100))
 
@@ -505,8 +535,8 @@ def test_dont_concatenate_single_chunks(shape, chunks):
 
 
 def test_intersect_nan():
-    old_chunks = ((float("nan"), float("nan")), (8,))
-    new_chunks = ((float("nan"), float("nan")), (4, 4))
+    old_chunks = ((np.nan, np.nan), (8,))
+    new_chunks = ((np.nan, np.nan), (4, 4))
 
     result = list(intersect_chunks(old_chunks, new_chunks))
     expected = [
@@ -519,8 +549,8 @@ def test_intersect_nan():
 
 
 def test_intersect_nan_single():
-    old_chunks = ((float("nan"),), (10,))
-    new_chunks = ((float("nan"),), (5, 5))
+    old_chunks = ((np.nan,), (10,))
+    new_chunks = ((np.nan,), (5, 5))
 
     result = list(intersect_chunks(old_chunks, new_chunks))
     expected = [
@@ -531,9 +561,8 @@ def test_intersect_nan_single():
 
 
 def test_intersect_nan_long():
-
-    old_chunks = (tuple([float("nan")] * 4), (10,))
-    new_chunks = (tuple([float("nan")] * 4), (5, 5))
+    old_chunks = (tuple([np.nan] * 4), (10,))
+    new_chunks = (tuple([np.nan] * 4), (5, 5))
     result = list(intersect_chunks(old_chunks, new_chunks))
     expected = [
         (((0, slice(0, None, None)), (0, slice(0, 5, None))),),
@@ -552,7 +581,7 @@ def test_rechunk_unknown_from_pandas():
     dd = pytest.importorskip("dask.dataframe")
     pd = pytest.importorskip("pandas")
 
-    arr = np.random.randn(50, 10)
+    arr = np.random.default_rng().standard_normal((50, 10))
     x = dd.from_pandas(pd.DataFrame(arr), 2).values
     result = x.rechunk((None, (5, 5)))
     assert np.isnan(x.chunks[0]).all()
@@ -596,7 +625,6 @@ def test_rechunk_unknown(x, chunks):
     y = dd.from_array(x).values
     result = y.rechunk(chunks)
     expected = x.rechunk(chunks)
-
     assert_chunks_match(result.chunks, expected.chunks)
     assert_eq(result, expected)
 
@@ -605,7 +633,7 @@ def test_rechunk_unknown_explicit():
     dd = pytest.importorskip("dask.dataframe")
     x = da.ones(shape=(10, 10), chunks=(5, 2))
     y = dd.from_array(x).values
-    result = y.rechunk(((float("nan"), float("nan")), (5, 5)))
+    result = y.rechunk(((np.nan, np.nan), (5, 5)))
     expected = x.rechunk((None, (5, 5)))
     assert_chunks_match(result.chunks, expected.chunks)
     assert_eq(result, expected)
@@ -628,8 +656,8 @@ def test_rechunk_unknown_raises():
 
 
 def test_old_to_new_single():
-    old = ((float("nan"), float("nan")), (8,))
-    new = ((float("nan"), float("nan")), (4, 4))
+    old = ((np.nan, np.nan), (8,))
+    new = ((np.nan, np.nan), (4, 4))
     result = _old_to_new(old, new)
 
     expected = [
@@ -641,8 +669,8 @@ def test_old_to_new_single():
 
 
 def test_old_to_new():
-    old = ((float("nan"),), (10,))
-    new = ((float("nan"),), (5, 5))
+    old = ((np.nan,), (10,))
+    new = ((np.nan,), (5, 5))
     result = _old_to_new(old, new)
     expected = [
         [[(0, slice(0, None, None))]],
@@ -653,8 +681,8 @@ def test_old_to_new():
 
 
 def test_old_to_new_large():
-    old = (tuple([float("nan")] * 4), (10,))
-    new = (tuple([float("nan")] * 4), (5, 5))
+    old = (tuple([np.nan] * 4), (10,))
+    new = (tuple([np.nan] * 4), (5, 5))
 
     result = _old_to_new(old, new)
     expected = [
@@ -670,9 +698,8 @@ def test_old_to_new_large():
 
 
 def test_changing_raises():
-    nan = float("nan")
     with pytest.raises(ValueError) as record:
-        _old_to_new(((nan, nan), (4, 4)), ((nan, nan, nan), (4, 4)))
+        _old_to_new(((np.nan, np.nan), (4, 4)), ((np.nan, np.nan, np.nan), (4, 4)))
 
     assert "unchanging" in str(record.value)
 
@@ -765,12 +792,15 @@ def test_rechunk_auto_image_stack(n):
 
     with dask.config.set({"array.chunk-size": "7MiB"}):
         z = x.rechunk("auto")
-        assert z.chunks == ((5,) * (n // 5), (1000,), (1000,))
+        if n == 100:
+            assert z.chunks == ((7,) * 14 + (2,), (1000,), (1000,))
+        else:
+            assert z.chunks == ((7,) * 142 + (6,), (1000,), (1000,))
 
     with dask.config.set({"array.chunk-size": "1MiB"}):
         x = da.ones((n, 1000, 1000), chunks=(1, 1000, 1000), dtype="float64")
         z = x.rechunk("auto")
-        assert z.chunks == ((1,) * n, (250,) * 4, (250,) * 4)
+        assert z.chunks == ((1,) * n, (362, 362, 276), (362, 362, 276))
 
 
 def test_rechunk_down():
@@ -781,14 +811,14 @@ def test_rechunk_down():
 
     with dask.config.set({"array.chunk-size": "1MiB"}):
         z = y.rechunk("auto")
-        assert z.chunks == ((5,) * 20, (250,) * 4, (250,) * 4)
+        assert z.chunks == ((4,) * 25, (511, 489), (511, 489))
 
     with dask.config.set({"array.chunk-size": "1MiB"}):
         z = y.rechunk({0: "auto"})
         assert z.chunks == ((1,) * 100, (1000,), (1000,))
 
         z = y.rechunk({1: "auto"})
-        assert z.chunks == ((10,) * 10, (100,) * 10, (1000,))
+        assert z.chunks == ((10,) * 10, (104,) * 9 + (64,), (1000,))
 
 
 def test_rechunk_zero():
@@ -885,7 +915,7 @@ def test_balance_raises():
 def test_balance_basics_2d():
     N = 210
 
-    x = da.from_array(np.random.uniform(size=(N, N)))
+    x = da.from_array(np.random.default_rng().uniform(size=(N, N)))
     balanced = x.rechunk(chunks=(100, 100), balance=True)
     unbalanced = x.rechunk(chunks=(100, 100), balance=False)
     assert unbalanced.chunks == ((100, 100, 10), (100, 100, 10))
@@ -895,7 +925,7 @@ def test_balance_basics_2d():
 def test_balance_2d_negative_dimension():
     N = 210
 
-    x = da.from_array(np.random.uniform(size=(N, N)))
+    x = da.from_array(np.random.default_rng().uniform(size=(N, N)))
     balanced = x.rechunk(chunks=(100, -1), balance=True)
     unbalanced = x.rechunk(chunks=(100, -1), balance=False)
     assert unbalanced.chunks == ((100, 100, 10), (N,))
@@ -905,7 +935,7 @@ def test_balance_2d_negative_dimension():
 def test_balance_different_inputs():
     N = 210
 
-    x = da.from_array(np.random.uniform(size=(N, N)))
+    x = da.from_array(np.random.default_rng().uniform(size=(N, N)))
     balanced = x.rechunk(chunks=("10MB", -1), balance=True)
     unbalanced = x.rechunk(chunks=("10MB", -1), balance=False)
     assert balanced.chunks == unbalanced.chunks
@@ -933,7 +963,7 @@ def test_balance_split_into_n_chunks():
 
     for N in array_lens:
         for nchunks in range(1, 20):
-            x = da.from_array(np.random.uniform(size=N))
+            x = da.from_array(np.random.default_rng().uniform(size=N))
             y = x.rechunk(chunks=len(x) // nchunks, balance=True)
             assert len(y.chunks[0]) == nchunks
 
