@@ -8,7 +8,6 @@ from contextlib import contextmanager
 from functools import partial
 
 import pytest
-from packaging.version import parse as parse_version
 
 s3fs = pytest.importorskip("s3fs")
 boto3 = pytest.importorskip("boto3")
@@ -78,6 +77,9 @@ def s3_base():
     with ensure_safe_environment_variables():
         os.environ["AWS_ACCESS_KEY_ID"] = "foobar_key"
         os.environ["AWS_SECRET_ACCESS_KEY"] = "foobar_secret"
+        # Ignore any local AWS credentials/config files as they can interfere with moto
+        os.environ["AWS_SHARED_CREDENTIALS_FILE"] = ""
+        os.environ["AWS_CONFIG_FILE"] = ""
 
         # pipe to null to avoid logging in terminal
         proc = subprocess.Popen(
@@ -377,7 +379,7 @@ def test_read_bytes_delimited(s3, blocksize, s3so):
 
 @pytest.mark.parametrize(
     "fmt,blocksize",
-    [(fmt, None) for fmt in compr] + [(fmt, 10) for fmt in compr],  # type: ignore
+    [(fmt, None) for fmt in compr] + [(fmt, 10) for fmt in compr],
 )
 def test_compression(s3, fmt, blocksize, s3so):
     if fmt not in compress:
@@ -435,28 +437,21 @@ def test_modification_time_read_bytes(s3, s3so):
     assert [aa._key for aa in concat(a)] != [cc._key for cc in concat(c)]
 
 
-@pytest.mark.parametrize("engine", ["pyarrow", "fastparquet"])
+@pytest.mark.parametrize(
+    "engine",
+    [
+        "pyarrow",
+        pytest.param("fastparquet", marks=pytest.mark.xfail_with_pyarrow_strings),
+    ],
+)
 @pytest.mark.parametrize("metadata_file", [True, False])
 def test_parquet(s3, engine, s3so, metadata_file):
-    import s3fs
-
     dd = pytest.importorskip("dask.dataframe")
     pd = pytest.importorskip("pandas")
     np = pytest.importorskip("numpy")
-
-    lib = pytest.importorskip(engine)
-    lib_version = parse_version(lib.__version__)
-    if engine == "pyarrow" and lib_version < parse_version("0.13.1"):
-        pytest.skip("pyarrow < 0.13.1 not supported for parquet")
-    if (
-        engine == "pyarrow"
-        and lib_version.major == 2
-        and parse_version(s3fs.__version__) > parse_version("0.5.0")
-    ):
-        pytest.skip("#7056 - new s3fs not supported before pyarrow 3.0")
+    pytest.importorskip(engine)
 
     url = "s3://%s/test.parquet" % test_bucket_name
-
     data = pd.DataFrame(
         {
             "i32": np.arange(1000, dtype=np.int32),
@@ -489,7 +484,6 @@ def test_parquet(s3, engine, s3so, metadata_file):
     # Check that `open_file_options` arguments are
     # really passed through to fsspec
     if fsspec_parquet:
-
         # Passing `open_file_options` kwargs will fail
         # if you set an unsupported engine
         with pytest.raises(ValueError):
@@ -548,7 +542,13 @@ def test_parquet(s3, engine, s3so, metadata_file):
     dd.utils.assert_eq(data, df4)
 
 
-@pytest.mark.parametrize("engine", ["pyarrow", "fastparquet"])
+@pytest.mark.parametrize(
+    "engine",
+    [
+        "pyarrow",
+        pytest.param("fastparquet", marks=pytest.mark.xfail_with_pyarrow_strings),
+    ],
+)
 def test_parquet_append(s3, engine, s3so):
     pytest.importorskip(engine)
     dd = pytest.importorskip("dask.dataframe")
@@ -603,7 +603,13 @@ def test_parquet_append(s3, engine, s3so):
     )
 
 
-@pytest.mark.parametrize("engine", ["pyarrow", "fastparquet"])
+@pytest.mark.parametrize(
+    "engine",
+    [
+        "pyarrow",
+        pytest.param("fastparquet", marks=pytest.mark.xfail_with_pyarrow_strings),
+    ],
+)
 def test_parquet_wstoragepars(s3, s3so, engine):
     pytest.importorskip(engine)
     dd = pytest.importorskip("dask.dataframe")
