@@ -1,4 +1,5 @@
 try:
+    import dask.dataframe._pyarrow_compat
     from dask.base import compute
     from dask.dataframe import backends, dispatch, rolling
     from dask.dataframe.core import (
@@ -15,9 +16,10 @@ try:
     from dask.dataframe.io import (
         demo,
         from_array,
-        from_bcolz,
         from_dask_array,
         from_delayed,
+        from_dict,
+        from_map,
         from_pandas,
         read_csv,
         read_fwf,
