@@ -13,6 +13,7 @@ import pandas as pd
 import dask.array as da
 from dask.base import is_dask_collection, tokenize
 from dask.blockwise import BlockwiseDepDict, blockwise
+from dask.dataframe._compat import is_any_real_numeric_dtype
 from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.core import (
     DataFrame,
@@ -20,10 +21,12 @@ from dask.dataframe.core import (
     Series,
     _concat,
     _emulate,
+    _Frame,
     apply_and_enforce,
     has_parallel_type,
     new_dd_object,
 )
+from dask.dataframe.dispatch import meta_lib_from_array
 from dask.dataframe.io.utils import DataFrameIOFunction
 from dask.dataframe.utils import (
     check_meta,
@@ -58,7 +61,7 @@ def _meta_from_array(x, columns=None, index=None, meta=None):
         index = index._meta
 
     if meta is None:
-        meta = pd.DataFrame()
+        meta = meta_lib_from_array(x).DataFrame()
 
     if getattr(x.dtype, "names", None) is not None:
         # record array has named columns
@@ -277,7 +280,7 @@ def from_pandas(
     if not nrows:
         return new_dd_object({(name, 0): data}, name, data, [None, None])
 
-    if data.index.isna().any() and not data.index.is_numeric():
+    if data.index.isna().any() and not is_any_real_numeric_dtype(data.index):
         raise NotImplementedError(
             "Index in passed data is non-numeric and contains nulls, which Dask does not entirely support.\n"
             "Consider passing `data.loc[~data.isna()]` instead."
@@ -1074,5 +1077,30 @@ def from_map(
     return new_dd_object(graph, name, meta, divisions)
 
 
+def to_backend(ddf: _Frame, backend: str | None = None, **kwargs):
+    """Move a DataFrame collection to a new backend
+
+    Parameters
+    ----------
+    ddf : DataFrame, Series, or Index
+        The input dataframe collection.
+    backend : str, Optional
+        The name of the new backend to move to. The default
+        is the current "dataframe.backend" configuration.
+
+    Returns
+    -------
+    dask.DataFrame, dask.Series or dask.Index
+        A new dataframe collection with the backend
+        specified by ``backend``.
+    """
+    # Get desired backend
+    backend = backend or dataframe_creation_dispatch.backend
+    # Check that "backend" has a registered entrypoint
+    backend_entrypoint = dataframe_creation_dispatch.dispatch(backend)
+    # Call `DataFrameBackendEntrypoint.to_backend`
+    return backend_entrypoint.to_backend(ddf, **kwargs)
+
+
 DataFrame.to_records.__doc__ = to_records.__doc__
 DataFrame.to_bag.__doc__ = to_bag.__doc__
