@@ -2,9 +2,9 @@ import copy
 
 from fsspec.core import get_fs_token_paths
 from fsspec.utils import stringify_path
-from packaging.version import parse as parse_version
 
 from dask.base import compute_as_if_collection, tokenize
+from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.core import DataFrame, Scalar
 from dask.dataframe.io.io import from_map
 from dask.dataframe.io.orc.utils import ORCEngine
@@ -49,25 +49,22 @@ class ORCFunctionWrapper(DataFrameIOFunction):
         )
         if self.index:
             _df.set_index(self.index, inplace=True)
+
         return _df
 
 
 def _get_engine(engine, write=False):
     # Get engine
     if engine == "pyarrow":
-        import pyarrow as pa
-
         from dask.dataframe.io.orc.arrow import ArrowORCEngine
 
-        if write and parse_version(pa.__version__) < parse_version("4.0.0"):
-            raise ValueError("to_orc is not supported for pyarrow<4.0.0")
-
         return ArrowORCEngine
     elif not isinstance(engine, ORCEngine):
         raise TypeError("engine must be 'pyarrow', or an ORCEngine object")
     return engine
 
 
+@dataframe_creation_dispatch.register_inplace("pandas")
 def read_orc(
     path,
     engine="pyarrow",
