@@ -4,10 +4,10 @@ import contextlib
 import math
 import warnings
 
+import pandas as pd
 import tlz as toolz
 from fsspec.core import get_fs_token_paths
 from fsspec.utils import stringify_path
-from packaging.version import parse as parse_version
 
 import dask
 from dask.base import tokenize
@@ -15,7 +15,11 @@ from dask.blockwise import BlockIndex
 from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.core import DataFrame, Scalar
 from dask.dataframe.io.io import from_map
-from dask.dataframe.io.parquet.utils import Engine, _sort_and_analyze_paths
+from dask.dataframe.io.parquet.utils import (
+    Engine,
+    _sort_and_analyze_paths,
+    _split_user_options,
+)
 from dask.dataframe.io.utils import DataFrameIOFunction, _is_local_fs
 from dask.dataframe.methods import concat
 from dask.delayed import Delayed
@@ -45,6 +49,7 @@ class ParquetFunctionWrapper(DataFrameIOFunction):
         meta,
         columns,
         index,
+        dtype_backend,
         kwargs,
         common_kwargs,
     ):
@@ -53,6 +58,7 @@ class ParquetFunctionWrapper(DataFrameIOFunction):
         self.meta = meta
         self._columns = columns
         self.index = index
+        self.dtype_backend = dtype_backend
 
         # `kwargs` = user-defined kwargs to be passed
         #            identically for all partitions.
@@ -78,12 +84,12 @@ class ParquetFunctionWrapper(DataFrameIOFunction):
             self.meta,
             columns,
             self.index,
+            self.dtype_backend,
             None,  # Already merged into common_kwargs
             self.common_kwargs,
         )
 
     def __call__(self, part):
-
         if not isinstance(part, list):
             part = [part]
 
@@ -181,13 +187,16 @@ def read_parquet(
     index=None,
     storage_options=None,
     engine="auto",
+    use_nullable_dtypes: bool | None = None,
+    dtype_backend=None,
     calculate_divisions=None,
     ignore_metadata_file=False,
     metadata_task_size=None,
-    split_row_groups=False,
-    chunksize=None,
+    split_row_groups="infer",
+    blocksize="default",
     aggregate_files=None,
     parquet_file_extension=(".parq", ".parquet", ".pq"),
+    filesystem=None,
     **kwargs,
 ):
     """
@@ -241,6 +250,8 @@ def read_parquet(
         data written by dask/fastparquet, not otherwise.
     storage_options : dict, default None
         Key/value pairs to be passed on to the file-system backend, if any.
+        Note that the default file-system backend can be configured with the
+        ``filesystem`` argument, described below.
     open_file_options : dict, default None
         Key/value arguments to be passed along to ``AbstractFileSystem.open``
         when each parquet data file is open for reading. Experimental
@@ -252,6 +263,20 @@ def read_parquet(
     engine : {'auto', 'pyarrow', 'fastparquet'}, default 'auto'
         Parquet library to use. Defaults to 'auto', which uses ``pyarrow`` if
         it is installed, and falls back to ``fastparquet`` otherwise.
+    use_nullable_dtypes : {False, True}
+        Whether to use extension dtypes for the resulting ``DataFrame``.
+        ``use_nullable_dtypes=True`` is only supported when ``engine="pyarrow"``.
+
+        .. note::
+
+            This option is deprecated. Use "dtype_backend" instead.
+
+    dtype_backend : {'numpy_nullable', 'pyarrow'}, defaults to NumPy backed DataFrames
+        Which dtype_backend to use, e.g. whether a DataFrame should have NumPy arrays,
+        nullable dtypes are used for all dtypes that have a nullable implementation
+        when 'numpy_nullable' is set, pyarrow is used for all dtypes if 'pyarrow'
+        is set.
+        ``dtype_backend="pyarrow"`` requires ``pandas`` 1.5+.
     calculate_divisions : bool, default False
         Whether to use min/max statistics from the footer metadata (or global
         ``_metadata`` file) to calculate divisions for the output DataFrame
@@ -275,22 +300,22 @@ def read_parquet(
         The default values for local and remote filesystems can be specified
         with the "metadata-task-size-local" and "metadata-task-size-remote"
         config fields, respectively (see "dataframe.parquet").
-    split_row_groups : bool or int, default False
+    split_row_groups : 'infer', 'adaptive', bool, or int, default 'infer'
         If True, then each output dataframe partition will correspond to a single
         parquet-file row-group. If False, each partition will correspond to a
         complete file.  If a positive integer value is given, each dataframe
         partition will correspond to that number of parquet row-groups (or fewer).
-    chunksize : int or str, default None
-        WARNING: The ``chunksize`` argument will be deprecated in the future.
-        Please use ``split_row_groups`` to specify how many row-groups should be
-        mapped to each output partition. If you strongly oppose the deprecation of
-        ``chunksize``, please comment at https://github.com/dask/dask/issues/9043".
-
+        If 'adaptive', the metadata of each file will be used to ensure that every
+        partition satisfies ``blocksize``. If 'infer' (the default), the
+        uncompressed storage-size metadata in the first file will be used to
+        automatically set ``split_row_groups`` to either 'adaptive' or ``False``.
+    blocksize : int or str, default 'default'
         The desired size of each output ``DataFrame`` partition in terms of total
-        (uncompressed) parquet storage space. If specified, adjacent row-groups
-        and/or files will be aggregated into the same output partition until the
-        cumulative ``total_byte_size`` parquet-metadata statistic reaches this
-        value. Use `aggregate_files` to enable/disable inter-file aggregation.
+        (uncompressed) parquet storage space. This argument is currenlty used to
+        set the default value of ``split_row_groups`` (using row-group metadata
+        from a single file), and will be ignored if ``split_row_groups`` is not
+        set to 'infer' or 'adaptive'. Default may be engine-dependant, but is
+        128 MiB for the 'pyarrow' and 'fastparquet' engines.
     aggregate_files : bool or str, default None
         WARNING: The ``aggregate_files`` argument will be deprecated in the future.
         Please consider using ``from_map`` to create a DataFrame collection with a
@@ -298,10 +323,10 @@ def read_parquet(
         ``aggregate_files``, comment at https://github.com/dask/dask/issues/9051".
 
         Whether distinct file paths may be aggregated into the same output
-        partition. This parameter is only used when `chunksize` is specified
-        or when `split_row_groups` is an integer >1. A setting of True means
-        that any two file paths may be aggregated into the same output partition,
-        while False means that inter-file aggregation is prohibited.
+        partition. This parameter is only used when `split_row_groups` is set to
+        'infer', 'adaptive' or to an integer >1. A setting of True means that any
+        two file paths may be aggregated into the same output partition, while
+        False means that inter-file aggregation is prohibited.
 
         For "hive-partitioned" datasets, a "partition"-column name can also be
         specified. In this case, we allow the aggregation of any two files
@@ -337,19 +362,34 @@ def read_parquet(
         unsupported metadata files (like Spark's '_SUCCESS' and 'crc' files).
         It may be necessary to change this argument if the data files in your
         parquet dataset do not end in ".parq", ".parquet", or ".pq".
+    filesystem: "fsspec", "arrow", or fsspec.AbstractFileSystem backend to use.
+        Note that the "fastparquet" engine only supports "fsspec" or an explicit
+        ``pyarrow.fs.AbstractFileSystem`` object. Default is "fsspec".
+    dataset: dict, default None
+        Dictionary of options to use when creating a ``pyarrow.dataset.Dataset``
+        or ``fastparquet.ParquetFile`` object. These options may include a
+        "filesystem" key (or "fs" for the "fastparquet" engine) to configure
+        the desired file-system backend. However, the top-level ``filesystem``
+        argument will always take precedence.
+
+        NOTE: For the "pyarrow" engine, the ``dataset`` options may include a
+        "partitioning" key. However, since ``pyarrow.dataset.Partitioning``
+        objects cannot be serialized, the value can be a dict of key-word
+        arguments for the ``pyarrow.dataset.partitioning`` API
+        (e.g. ``dataset={"partitioning": {"flavor": "hive", "schema": ...}}``).
+        Note that partitioned columns will not be converted to categorical
+        dtypes when a custom partitioning schema is specified in this way.
+    read: dict, default None
+        Dictionary of options to pass through to ``engine.read_partitions``
+        using the ``read`` key-word argument.
+    arrow_to_pandas: dict, default None
+        Dictionary of options to use when converting from ``pyarrow.Table`` to
+        a pandas ``DataFrame`` object. Only used by the "arrow" engine.
     **kwargs: dict (of dicts)
-        Passthrough key-word arguments for read backend.
-        The top-level keys correspond to the appropriate operation type, and
-        the second level corresponds to the kwargs that will be passed on to
-        the underlying ``pyarrow`` or ``fastparquet`` function.
-        Supported top-level keys: 'dataset' (for opening a ``pyarrow`` dataset),
-        'file' or 'dataset' (for opening a ``fastparquet.ParquetFile``), 'read'
-        (for the backend read function), 'arrow_to_pandas' (for controlling the
-        arguments passed to convert from a ``pyarrow.Table.to_pandas()``).
-        Any element of kwargs that is not defined under these top-level keys
-        will be passed through to the `engine.read_partitions` classmethod as a
-        stand-alone argument (and will be ignored by the engine implementations
-        defined in ``dask.dataframe``).
+        Options to pass through to ``engine.read_partitions`` as stand-alone
+        key-word arguments. Note that these options will be ignored by the
+        engines defined in ``dask.dataframe``, but may be used by other custom
+        implementations.
 
     Examples
     --------
@@ -360,15 +400,19 @@ def read_parquet(
     to_parquet
     pyarrow.parquet.ParquetDataset
     """
-
-    # "Pre-deprecation" warning for `chunksize`
-    if chunksize:
+    # Handle `chunksize` deprecation
+    if "chunksize" in kwargs:
+        if blocksize != "default":
+            raise ValueError(
+                "The `chunksize` argument is now deprecated. "
+                "Please use the `blocksize` argument instead."
+            )
+        blocksize = kwargs.pop("chunksize")
         warnings.warn(
-            "The `chunksize` argument will be deprecated in the future. "
-            "Please use `split_row_groups` to specify how many row-groups "
-            "should be mapped to each output partition.\n\n"
-            "If you strongly oppose the deprecation of `chunksize`, please "
-            "comment at https://github.com/dask/dask/issues/9043",
+            "The `chunksize` argument is deprecated, and will be "
+            "removed in a future release. Setting the `blocksize` "
+            "argument instead. Please see documentation on the "
+            "`blocksize` argument for more information.",
             FutureWarning,
         )
 
@@ -433,13 +477,16 @@ def read_parquet(
         "index": index,
         "storage_options": storage_options,
         "engine": engine,
+        "use_nullable_dtypes": use_nullable_dtypes,
+        "dtype_backend": dtype_backend,
         "calculate_divisions": calculate_divisions,
         "ignore_metadata_file": ignore_metadata_file,
         "metadata_task_size": metadata_task_size,
         "split_row_groups": split_row_groups,
-        "chunksize": chunksize,
+        "blocksize": blocksize,
         "aggregate_files": aggregate_files,
         "parquet_file_extension": parquet_file_extension,
+        "filesystem": filesystem,
         **kwargs,
     }
 
@@ -460,7 +507,23 @@ def read_parquet(
     # Update input_kwargs
     input_kwargs.update({"columns": columns, "engine": engine})
 
-    fs, _, paths = get_fs_token_paths(path, mode="rb", storage_options=storage_options)
+    # Process and split user options
+    (
+        dataset_options,
+        read_options,
+        open_file_options,
+        other_options,
+    ) = _split_user_options(**kwargs)
+
+    # Extract global filesystem and paths
+    fs, paths, dataset_options, open_file_options = engine.extract_filesystem(
+        path,
+        filesystem,
+        dataset_options,
+        open_file_options,
+        storage_options,
+    )
+    read_options["open_file_options"] = open_file_options
     paths = sorted(paths, key=natural_sort_key)  # numeric rather than glob ordering
 
     auto_index_allowed = False
@@ -470,20 +533,31 @@ def read_parquet(
     if index and isinstance(index, str):
         index = [index]
 
+    if split_row_groups in ("infer", "adaptive"):
+        # Using blocksize to plan partitioning
+        blocksize = engine.default_blocksize() if blocksize == "default" else blocksize
+    else:
+        # Not using blocksize - Set to `None`
+        blocksize = None
+
     read_metadata_result = engine.read_metadata(
         fs,
         paths,
         categories=categories,
         index=index,
+        use_nullable_dtypes=use_nullable_dtypes,
+        dtype_backend=dtype_backend,
         gather_statistics=calculate_divisions,
         filters=filters,
         split_row_groups=split_row_groups,
-        chunksize=chunksize,
+        blocksize=blocksize,
         aggregate_files=aggregate_files,
         ignore_metadata_file=ignore_metadata_file,
         metadata_task_size=metadata_task_size,
         parquet_file_extension=parquet_file_extension,
-        **kwargs,
+        dataset=dataset_options,
+        read=read_options,
+        **other_options,
     )
 
     # In the future, we may want to give the engine the
@@ -500,14 +574,15 @@ def read_parquet(
         # may be stored in the first element of `parts`
         common_kwargs = parts[0].pop("common_kwargs", {})
         aggregation_depth = parts[0].pop("aggregation_depth", aggregation_depth)
+        split_row_groups = parts[0].pop("split_row_groups", split_row_groups)
 
     # Parse dataset statistics from metadata (if available)
-    parts, divisions, index, index_in_columns = process_statistics(
+    parts, divisions, index = process_statistics(
         parts,
         statistics,
         filters,
         index,
-        chunksize,
+        (blocksize if split_row_groups is True else None),
         split_row_groups,
         fs,
         aggregation_depth,
@@ -515,18 +590,10 @@ def read_parquet(
 
     # Account for index and columns arguments.
     # Modify `meta` dataframe accordingly
-    meta, index, columns = set_index_columns(
-        meta, index, columns, index_in_columns, auto_index_allowed
-    )
+    meta, index, columns = set_index_columns(meta, index, columns, auto_index_allowed)
     if meta.index.name == NONE_LABEL:
         meta.index.name = None
 
-    # Set the index that was previously treated as a column
-    if index_in_columns:
-        meta = meta.set_index(index)
-        if meta.index.name == NONE_LABEL:
-            meta.index.name = None
-
     if len(divisions) < 2:
         # empty dataframe - just use meta
         divisions = (None, None)
@@ -540,6 +607,7 @@ def read_parquet(
             meta,
             columns,
             index,
+            dtype_backend,
             {},  # All kwargs should now be in `common_kwargs`
             common_kwargs,
         )
@@ -552,7 +620,7 @@ def read_parquet(
     if "retries" not in annotations and not _is_local_fs(fs):
         ctx = dask.annotate(retries=5)
     else:
-        ctx = contextlib.nullcontext()
+        ctx = contextlib.nullcontext()  # type: ignore
 
     with ctx:
         # Construct the output collection with from_map
@@ -587,7 +655,13 @@ def read_parquet_part(fs, engine, meta, part, columns, index, kwargs):
             # Part kwargs expected
             func = engine.read_partition
             dfs = [
-                func(fs, rg, columns.copy(), index, **toolz.merge(kwargs, kw))
+                func(
+                    fs,
+                    rg,
+                    columns.copy(),
+                    index,
+                    **toolz.merge(kwargs, kw),
+                )
                 for (rg, kw) in part
             ]
             df = concat(dfs, axis=0) if len(dfs) > 1 else dfs[0]
@@ -595,14 +669,22 @@ def read_parquet_part(fs, engine, meta, part, columns, index, kwargs):
             # No part specific kwargs, let engine read
             # list of parts at once
             df = engine.read_partition(
-                fs, [p[0] for p in part], columns.copy(), index, **kwargs
+                fs,
+                [p[0] for p in part],
+                columns.copy(),
+                index,
+                **kwargs,
             )
     else:
         # NOTE: `kwargs` are the same for all parts, while `part_kwargs` may
         #       be different for each part.
         rg, part_kwargs = part
         df = engine.read_partition(
-            fs, rg, columns, index, **toolz.merge(kwargs, part_kwargs)
+            fs,
+            rg,
+            columns,
+            index,
+            **toolz.merge(kwargs, part_kwargs),
         )
 
     if meta.columns.name:
@@ -632,6 +714,7 @@ def to_parquet(
     compute_kwargs=None,
     schema="infer",
     name_function=None,
+    filesystem=None,
     **kwargs,
 ):
     """Store Dask.dataframe to Parquet files
@@ -712,6 +795,9 @@ def to_parquet(
         If not specified, files will created using the convention
         ``part.0.parquet``, ``part.1.parquet``, ``part.2.parquet``, ...
         and so on for each partition in the DataFrame.
+    filesystem: "fsspec", "arrow", or fsspec.AbstractFileSystem backend to use.
+        Note that the "fastparquet" engine only supports "fsspec" or an explicit
+        ``pyarrow.fs.AbstractFileSystem`` object. Default is "fsspec".
     **kwargs :
         Extra options to be passed on to the specific backend.
 
@@ -767,9 +853,16 @@ def to_parquet(
 
     if hasattr(path, "name"):
         path = stringify_path(path)
-    fs, _, _ = get_fs_token_paths(path, mode="wb", storage_options=storage_options)
-    # Trim any protocol information from the path before forwarding
-    path = fs._strip_protocol(path)
+
+    fs, _paths, _, _ = engine.extract_filesystem(
+        path,
+        filesystem=filesystem,
+        dataset_options={},
+        open_file_options={},
+        storage_options=storage_options,
+    )
+    assert len(_paths) == 1, "only one path"
+    path = _paths[0]
 
     if overwrite:
         if append:
@@ -785,11 +878,13 @@ def to_parquet(
                 ):
                     path_with_slash = path.rstrip("/") + "/"  # ensure trailing slash
                     for input in layer.inputs:
-                        if input["piece"][0].startswith(path_with_slash):
-                            raise ValueError(
-                                "Reading and writing to the same parquet file within the "
-                                "same task graph is not supported."
-                            )
+                        # Note that `input` may be either `dict` or `List[dict]`
+                        for piece_dict in input if isinstance(input, list) else [input]:
+                            if piece_dict["piece"][0].startswith(path_with_slash):
+                                raise ValueError(
+                                    "Reading and writing to the same parquet file within "
+                                    "the same task graph is not supported."
+                                )
 
             # Don't remove the directory if it's the current working directory
             if _is_local_fs(fs):
@@ -825,7 +920,7 @@ def to_parquet(
                 "will be set to the index (and renamed to None)."
             )
 
-    # There are some "resrved" names that may be used as the default column
+    # There are some "reserved" names that may be used as the default column
     # name after resetting the index. However, we don't want to treat it as
     # a "special" name if the string is already used as a "real" column name.
     reserved_names = []
@@ -1152,19 +1247,12 @@ def get_engine(engine):
         return eng
 
     elif engine in ("pyarrow", "arrow", "pyarrow-dataset"):
-        pa = import_required("pyarrow", "`pyarrow` not installed")
-        pa_version = parse_version(pa.__version__)
+        import_required("pyarrow", "`pyarrow` not installed")
 
         if engine in ("pyarrow-dataset", "arrow"):
             engine = "pyarrow"
 
         if engine == "pyarrow":
-            if pa_version.major < 1:
-                raise ImportError(
-                    f"pyarrow-{pa_version.major} does not support the "
-                    f"pyarrow.dataset API. Please install pyarrow>=1."
-                )
-
             from dask.dataframe.io.parquet.arrow import ArrowDatasetEngine
 
             _ENGINES[engine] = eng = ArrowDatasetEngine
@@ -1182,11 +1270,13 @@ def get_engine(engine):
 #####################
 
 
-def sorted_columns(statistics):
+def sorted_columns(statistics, columns=None):
     """Find sorted columns given row-group statistics
 
-    This finds all columns that are sorted, along with appropriate divisions
-    values for those columns
+    This finds all columns that are sorted, along with the
+    appropriate ``divisions`` for those columns. If the (optional)
+    ``columns`` argument is used, the search will be restricted
+    to the specified column set.
 
     Returns
     -------
@@ -1197,6 +1287,8 @@ def sorted_columns(statistics):
 
     out = []
     for i, c in enumerate(statistics[0]["columns"]):
+        if columns and c["name"] not in columns:
+            continue
         if not all(
             "min" in s["columns"][i] and "max" in s["columns"][i] for s in statistics
         ):
@@ -1268,15 +1360,30 @@ def apply_filters(parts, statistics, filters):
                     c = toolz.groupby("name", stats["columns"])[column][0]
                     min = c["min"]
                     max = c["max"]
+                    null_count = c.get("null_count", None)
                 except KeyError:
                     out_parts.append(part)
                     out_statistics.append(stats)
                 else:
                     if (
-                        operator in ("==", "=")
+                        # Must allow row-groups with "missing" stats
+                        (min is None and max is None and not null_count)
+                        # Check "is" and "is not" fiters first
+                        or operator == "is"
+                        and null_count
+                        or operator == "is not"
+                        and (not pd.isna(min) or not pd.isna(max))
+                        # Allow all-null row-groups if not fitering out nulls
+                        or operator != "is not"
+                        and min is None
+                        and max is None
+                        and null_count
+                        # Start conventional (non-null) fitering
+                        # (main/max cannot be None for remaining checks)
+                        or operator in ("==", "=")
                         and min <= value <= max
                         or operator == "!="
-                        and (min != value or max != value)
+                        and (null_count or min != value or max != value)
                         or operator == "<"
                         and min < value
                         or operator == "<="
@@ -1312,7 +1419,7 @@ def process_statistics(
     statistics,
     filters,
     index,
-    chunksize,
+    blocksize,
     split_row_groups,
     fs,
     aggregation_depth,
@@ -1320,7 +1427,6 @@ def process_statistics(
     """Process row-group column statistics in metadata
     Used in read_parquet.
     """
-    index_in_columns = False
     if statistics and len(parts) != len(statistics):
         # It is up to the Engine to guarantee that these
         # lists are the same length (if statistics are defined).
@@ -1335,6 +1441,7 @@ def process_statistics(
         )
         statistics = []
 
+    divisions = None
     if statistics:
         result = list(
             zip(
@@ -1350,57 +1457,48 @@ def process_statistics(
             parts, statistics = apply_filters(parts, statistics, filters)
 
         # Aggregate parts/statistics if we are splitting by row-group
-        if chunksize or (split_row_groups and int(split_row_groups) > 1):
+        if blocksize or (split_row_groups and int(split_row_groups) > 1):
             parts, statistics = aggregate_row_groups(
-                parts, statistics, chunksize, split_row_groups, fs, aggregation_depth
+                parts, statistics, blocksize, split_row_groups, fs, aggregation_depth
             )
 
-        out = sorted_columns(statistics)
+        # Convert str index to list
+        index = [index] if isinstance(index, str) else index
 
-        if index and isinstance(index, str):
-            index = [index]
-        if index and out:
-            # Only one valid column
-            out = [o for o in out if o["name"] in index]
-        if index is not False and len(out) == 1:
-            # Use only sorted column with statistics as the index
-            divisions = out[0]["divisions"]
-            if index is None:
-                index_in_columns = True
-                index = [out[0]["name"]]
-            elif index != [out[0]["name"]]:
-                raise ValueError(f"Specified index is invalid.\nindex: {index}")
-        elif index is not False and len(out) > 1:
-            if any(o["name"] == NONE_LABEL for o in out):
-                # Use sorted column matching NONE_LABEL as the index
-                [o] = [o for o in out if o["name"] == NONE_LABEL]
-                divisions = o["divisions"]
-                if index is None:
-                    index = [o["name"]]
-                    index_in_columns = True
-                elif index != [o["name"]]:
-                    raise ValueError(f"Specified index is invalid.\nindex: {index}")
-            else:
-                # Multiple sorted columns found, cannot autodetect the index
+        # TODO: Remove `filters` criteria below after deprecation cycle.
+        # We can then remove the `sorted_col_names` logic and warning.
+        # See: https://github.com/dask/dask/pull/9661
+        process_columns = index if index and len(index) == 1 else None
+        if filters:
+            process_columns = None
+
+        # Use statistics to define divisions
+        if process_columns or filters:
+            sorted_col_names = []
+            for sorted_column_info in sorted_columns(
+                statistics, columns=process_columns
+            ):
+                if index and sorted_column_info["name"] in index:
+                    divisions = sorted_column_info["divisions"]
+                    break
+                else:
+                    # Filtered columns may also be sorted
+                    sorted_col_names.append(sorted_column_info["name"])
+
+            if index is None and sorted_col_names:
+                assert bool(filters)  # Should only get here when filtering
                 warnings.warn(
-                    "Multiple sorted columns found %s, cannot\n "
-                    "autodetect index. Will continue without an index.\n"
-                    "To pick an index column, use the index= keyword; to \n"
-                    "silence this warning use index=False."
-                    "" % [o["name"] for o in out],
-                    RuntimeWarning,
+                    f"Sorted columns detected: {sorted_col_names}\n"
+                    f"Use the `index` argument to set a sorted column as your "
+                    f"index to create a DataFrame collection with known `divisions`.",
+                    UserWarning,
                 )
-                index = False
-                divisions = [None] * (len(parts) + 1)
-        else:
-            divisions = [None] * (len(parts) + 1)
-    else:
-        divisions = [None] * (len(parts) + 1)
 
-    return parts, divisions, index, index_in_columns
+    divisions = divisions or (None,) * (len(parts) + 1)
+    return parts, divisions, index
 
 
-def set_index_columns(meta, index, columns, index_in_columns, auto_index_allowed):
+def set_index_columns(meta, index, columns, auto_index_allowed):
     """Handle index/column arguments, and modify `meta`
     Used in read_parquet.
     """
@@ -1444,22 +1542,11 @@ def set_index_columns(meta, index, columns, index_in_columns, auto_index_allowed
                     "index: {} | column: {}".format(index, columns)
                 )
 
-        # Leaving index as a column in `meta`, because the index
-        # will be reset below (in case the index was detected after
-        # meta was created)
-        if index_in_columns:
-            meta = meta[columns + index]
-        else:
-            meta = meta[columns]
-
-    else:
-        meta = meta[list(columns)]
-
-    return meta, index, columns
+    return meta[list(columns)], index, columns
 
 
 def aggregate_row_groups(
-    parts, stats, chunksize, split_row_groups, fs, aggregation_depth
+    parts, stats, blocksize, split_row_groups, fs, aggregation_depth
 ):
     if not stats or not stats[0].get("file_path_0", None):
         return parts, stats
@@ -1468,9 +1555,9 @@ def aggregate_row_groups(
     stats_agg = []
 
     use_row_group_criteria = split_row_groups and int(split_row_groups) > 1
-    use_chunksize_criteria = bool(chunksize)
-    if use_chunksize_criteria:
-        chunksize = parse_bytes(chunksize)
+    use_blocksize_criteria = bool(blocksize)
+    if use_blocksize_criteria:
+        blocksize = parse_bytes(blocksize)
     next_part, next_stat = [parts[0].copy()], stats[0].copy()
     for i in range(1, len(parts)):
         stat, part = stats[i], parts[i]
@@ -1480,7 +1567,6 @@ def aggregate_row_groups(
         multi_path_allowed = False
 
         if aggregation_depth:
-
             # Criteria #2 for aggregating parts: The part does not include
             # row-group information, or both parts include the same kind
             # of row_group aggregation (all None, or all indices)
@@ -1514,11 +1600,11 @@ def aggregate_row_groups(
             else:
                 return False
 
-        def _check_chunksize_criteria(stat, next_stat):
-            if use_chunksize_criteria:
+        def _check_blocksize_criteria(stat, next_stat):
+            if use_blocksize_criteria:
                 return (
                     next_stat["total_byte_size"] + stat["total_byte_size"]
-                ) <= chunksize
+                ) <= blocksize
             else:
                 return False
 
@@ -1527,11 +1613,20 @@ def aggregate_row_groups(
 
         if (same_path or multi_path_allowed) and (
             _check_row_group_criteria(stat, next_stat)
-            or _check_chunksize_criteria(stat, next_stat)
+            or _check_blocksize_criteria(stat, next_stat)
         ):
-
             # Update part list
-            next_part.append(part)
+            next_piece = next_part[-1]["piece"]
+            this_piece = part["piece"]
+            if (
+                same_path
+                and len(next_piece) > 1
+                and next_piece[1] != [None]
+                and this_piece[1] != [None]
+            ):
+                next_piece[1].extend(this_piece[1])
+            else:
+                next_part.append(part)
 
             # Update Statistics
             next_stat["total_byte_size"] += stat["total_byte_size"]
