@@ -20,6 +20,7 @@ try:
 except ImportError:
     pass
 
+from dask import config
 from dask.base import tokenize
 
 #########################
@@ -28,6 +29,7 @@ from dask.base import tokenize
 from dask.dataframe.io.parquet.utils import (
     Engine,
     _get_aggregation_depth,
+    _infer_split_row_groups,
     _normalize_index_columns,
     _parse_pandas_metadata,
     _process_open_file_options,
@@ -124,7 +126,7 @@ class FastParquetEngine(Engine):
         dtypes,
         base_path,
         has_metadata_file,
-        chunksize,
+        blocksize,
         aggregation_depth,
     ):
         """Organize row-groups by file."""
@@ -159,7 +161,6 @@ class FastParquetEngine(Engine):
         file_row_group_column_stats = defaultdict(list)
         cmax_last = {}
         for rg, row_group in enumerate(pf.row_groups):
-
             # We can filter partition columns here without dealing
             # with statistics
             if (
@@ -214,13 +215,16 @@ class FastParquetEngine(Engine):
                     if column.meta_data.statistics:
                         cmin = None
                         cmax = None
+                        null_count = None
                         # TODO: Avoid use of `pf.statistics`
                         if pf.statistics["min"][name][0] is not None:
                             cmin = pf.statistics["min"][name][rg]
                             cmax = pf.statistics["max"][name][rg]
+                            null_count = pf.statistics["null_count"][name][rg]
                         elif dtypes[name] == "object":
                             cmin = column.meta_data.statistics.min_value
                             cmax = column.meta_data.statistics.max_value
+                            null_count = column.meta_data.statistics.null_count
                             # Older versions may not have cmin/cmax_value
                             if cmin is None:
                                 cmin = column.meta_data.statistics.min
@@ -234,13 +238,19 @@ class FastParquetEngine(Engine):
                             ):
                                 cmin = cmin.decode("utf-8")
                                 cmax = cmax.decode("utf-8")
+                            if isinstance(null_count, (bytes, bytearray)):
+                                null_count = null_count.decode("utf-8")
                         if isinstance(cmin, np.datetime64):
                             tz = getattr(dtypes[name], "tz", None)
                             cmin = pd.Timestamp(cmin, tz=tz)
                             cmax = pd.Timestamp(cmax, tz=tz)
                         last = cmax_last.get(name, None)
 
-                        if not (filters or chunksize or aggregation_depth):
+                        if not (
+                            filters
+                            or (blocksize and split_row_groups is True)
+                            or aggregation_depth
+                        ):
                             # Only think about bailing if we don't need
                             # stats for filtering
                             if cmin is None or (last and cmin < last):
@@ -261,14 +271,19 @@ class FastParquetEngine(Engine):
                                     "name": name,
                                     "min": cmin,
                                     "max": cmax,
+                                    "null_count": null_count,
                                 }
                             )
                         else:
-                            cstats += [cmin, cmax]
+                            cstats += [cmin, cmax, null_count]
                         cmax_last[name] = cmax
                     else:
                         if (
-                            not (filters or chunksize or aggregation_depth)
+                            not (
+                                filters
+                                or (blocksize and split_row_groups is True)
+                                or aggregation_depth
+                            )
                             and column.meta_data.num_values > 0
                         ):
                             # We are collecting statistics for divisions
@@ -369,14 +384,13 @@ class FastParquetEngine(Engine):
         gather_statistics,
         filters,
         split_row_groups,
-        chunksize,
+        blocksize,
         aggregate_files,
         ignore_metadata_file,
         metadata_task_size,
         parquet_file_extension,
         kwargs,
     ):
-
         # Define the parquet-file (pf) object to use for metadata,
         # Also, initialize `parts`.  If `parts` is populated here,
         # then each part will correspond to a file.  Otherwise, each part will
@@ -388,7 +402,6 @@ class FastParquetEngine(Engine):
         parts = []
         _metadata_exists = False
         if len(paths) == 1 and fs.isdir(paths[0]):
-
             # This is a directory.
             # Check if _metadata and/or _common_metadata files exists
             base = paths[0]
@@ -492,6 +505,61 @@ class FastParquetEngine(Engine):
                     "columns: {} | partitions: {}".format(pf.columns, pf.cats.keys())
                 )
 
+        # Set split_row_groups for desired partitioning behavior
+        #
+        # Expected behavior for split_row_groups + blocksize combinations:
+        # +======+==================+===========+=============================+
+        # | Case | split_row_groups | blocksize | Behavior                    |
+        # +======+==================+===========+=============================+
+        # |  A   |  "infer"         |  not None | Go to E or G (using md)     |
+        # +------+------------------+-----------+-----------------------------+
+        # |  B   |  "infer"         |  None     | Go to H                     |
+        # +------+------------------+-----------+-----------------------------+
+        # |  C   |  "adaptive"      |  not None | Go to E                     |
+        # +------+------------------+-----------+-----------------------------+
+        # |  D   |  "adaptive"      |  None     | Go to H                     |
+        # +======+==================+===========+=============================+
+        # |  E*  |  True            |  not None | Adaptive partitioning       |
+        # +------+------------------+-----------+-----------------------------+
+        # |  F   |  True            |  None     | 1 row-group per partition   |
+        # +------+------------------+-----------+-----------------------------+
+        # |  G*  |  False           |  not None | 1+ full files per partition |
+        # +------+------------------+-----------+-----------------------------+
+        # |  H   |  False           |  None     | 1 full file per partition   |
+        # +------+------------------+-----------+-----------------------------+
+        # |  I   |  n               |  N/A      | n row-groups per partition  |
+        # +======+==================+===========+=============================+
+        # NOTES:
+        # - Adaptive partitioning (E) means that the individual size of each
+        #   row-group will be accounted for when deciding how many row-groups
+        #   to map to each output partition.
+        # - E, G and I will only aggregate data from multiple files into the
+        #   same output partition if `bool(aggregate_files) == True`.
+        # - Default partitioning will correspond to either E or G. All other
+        #   behavior requires user input.
+
+        if split_row_groups == "infer":
+            if blocksize:
+                # Sample row-group sizes in first file
+                pf_sample = ParquetFile(
+                    paths[0],
+                    open_with=fs.open,
+                    **dataset_kwargs,
+                )
+                split_row_groups = _infer_split_row_groups(
+                    [rg.total_byte_size for rg in pf_sample.row_groups],
+                    blocksize,
+                    bool(aggregate_files),
+                )
+            else:
+                split_row_groups = False
+
+        if split_row_groups == "adaptive":
+            if blocksize:
+                split_row_groups = True
+            else:
+                split_row_groups = False
+
         return {
             "pf": pf,
             "paths": paths,
@@ -504,7 +572,7 @@ class FastParquetEngine(Engine):
             "index": index,
             "filters": filters,
             "split_row_groups": split_row_groups,
-            "chunksize": chunksize,
+            "blocksize": blocksize,
             "aggregate_files": aggregate_files,
             "aggregation_depth": aggregation_depth,
             "metadata_task_size": metadata_task_size,
@@ -516,7 +584,6 @@ class FastParquetEngine(Engine):
 
     @classmethod
     def _create_dd_meta(cls, dataset_info):
-
         # Collect necessary information from dataset_info
         pf = dataset_info["pf"]
         index = dataset_info["index"]
@@ -601,7 +668,6 @@ class FastParquetEngine(Engine):
 
     @classmethod
     def _construct_collection_plan(cls, dataset_info):
-
         # Collect necessary information from dataset_info
         fs = dataset_info["fs"]
         parts = dataset_info["parts"]
@@ -609,7 +675,7 @@ class FastParquetEngine(Engine):
         filters = dataset_info["filters"]
         pf = dataset_info["pf"]
         split_row_groups = dataset_info["split_row_groups"]
-        chunksize = dataset_info["chunksize"]
+        blocksize = dataset_info["blocksize"]
         gather_statistics = dataset_info["gather_statistics"]
         base_path = dataset_info["base"]
         aggregation_depth = dataset_info["aggregation_depth"]
@@ -642,7 +708,7 @@ class FastParquetEngine(Engine):
         # filtering even if the filter is on a paritioned column
         gather_statistics = _set_gather_statistics(
             gather_statistics,
-            chunksize,
+            blocksize,
             split_row_groups,
             aggregation_depth,
             filter_columns,
@@ -683,7 +749,7 @@ class FastParquetEngine(Engine):
             "dtypes": dtypes,
             "stat_col_indices": stat_col_indices,
             "aggregation_depth": aggregation_depth,
-            "chunksize": chunksize,
+            "blocksize": blocksize,
             "root_cats": pf.cats,
             "root_file_scheme": pf.file_scheme,
             "base_path": "" if base_path is None else base_path,
@@ -740,7 +806,6 @@ class FastParquetEngine(Engine):
         pf_or_files,
         dataset_info_kwargs,
     ):
-
         # Collect necessary information from dataset_info
         fs = dataset_info_kwargs["fs"]
         split_row_groups = dataset_info_kwargs["split_row_groups"]
@@ -748,7 +813,7 @@ class FastParquetEngine(Engine):
         stat_col_indices = dataset_info_kwargs["stat_col_indices"]
         filters = dataset_info_kwargs["filters"]
         dtypes = dataset_info_kwargs["dtypes"]
-        chunksize = dataset_info_kwargs["chunksize"]
+        blocksize = dataset_info_kwargs["blocksize"]
         aggregation_depth = dataset_info_kwargs["aggregation_depth"]
         base_path = dataset_info_kwargs.get("base_path", None)
         root_cats = dataset_info_kwargs.get("root_cats", None)
@@ -787,7 +852,7 @@ class FastParquetEngine(Engine):
             dtypes,
             base_path,
             has_metadata_file,
-            chunksize,
+            blocksize,
             aggregation_depth,
         )
 
@@ -818,21 +883,31 @@ class FastParquetEngine(Engine):
         paths,
         categories=None,
         index=None,
-        use_nullable_dtypes=False,
+        use_nullable_dtypes=None,
+        dtype_backend=None,
         gather_statistics=None,
         filters=None,
-        split_row_groups=False,
-        chunksize=None,
+        split_row_groups="adaptive",
+        blocksize=None,
         aggregate_files=None,
         ignore_metadata_file=False,
         metadata_task_size=None,
         parquet_file_extension=None,
         **kwargs,
     ):
-        if use_nullable_dtypes:
+        if use_nullable_dtypes is not None:
             raise ValueError(
                 "`use_nullable_dtypes` is not supported by the fastparquet engine"
             )
+        if dtype_backend is not None:
+            raise ValueError(
+                "`dtype_backend` is not supported by the fastparquet engine"
+            )
+        if config.get("dataframe.convert-string", False):
+            warnings.warn(
+                "`dataframe.convert-string` is not supported by the fastparquet engine",
+                category=UserWarning,
+            )
 
         # Stage 1: Collect general dataset information
         dataset_info = cls._collect_dataset_info(
@@ -843,7 +918,7 @@ class FastParquetEngine(Engine):
             gather_statistics,
             filters,
             split_row_groups,
-            chunksize,
+            blocksize,
             aggregate_files,
             ignore_metadata_file,
             metadata_task_size,
@@ -868,9 +943,9 @@ class FastParquetEngine(Engine):
         if len(parts):
             parts[0]["common_kwargs"] = common_kwargs
             parts[0]["aggregation_depth"] = dataset_info["aggregation_depth"]
+            parts[0]["split_row_groups"] = dataset_info["split_row_groups"]
 
         if len(parts) and len(parts[0]["piece"]) == 1:
-
             # Strip all partition-dependent or unnecessary
             # data from the `ParquetFile` object
             pf = dataset_info["pf"]
@@ -892,14 +967,13 @@ class FastParquetEngine(Engine):
         pieces,
         columns,
         index,
-        use_nullable_dtypes=False,
+        dtype_backend=None,
         categories=(),
         root_cats=None,
         root_file_scheme=None,
         base_path=None,
         **kwargs,
     ):
-
         null_index_name = False
         base_path = False if not root_cats else base_path
         if isinstance(index, list):
@@ -958,7 +1032,6 @@ class FastParquetEngine(Engine):
                 update_parquet_file = len(row_groups) < len(parquet_file.row_groups)
 
             elif parquet_file:
-
                 row_groups = []
                 for piece in pieces:
                     # `piece[1]` will contain actual row-group objects,
@@ -1071,7 +1144,6 @@ class FastParquetEngine(Engine):
         )
 
         with ExitStack() as stack:
-
             for fn, infile in zip(
                 fn_rg_map.keys(),
                 _open_input_files(
