@@ -5,15 +5,21 @@ from time import sleep
 import numpy as np
 import pandas as pd
 import pytest
+from packaging.version import Version
 
 import dask
 import dask.dataframe as dd
+from dask._compatibility import PY_VERSION
 from dask.dataframe._compat import tm
 from dask.dataframe.optimize import optimize_dataframe_getitem
 from dask.dataframe.utils import assert_eq
 from dask.layers import DataFrameIOLayer
 from dask.utils import dependency_depth, tmpdir, tmpfile
 
+# there's no support in upstream for writing HDF with extension dtypes yet.
+# see https://github.com/pandas-dev/pandas/issues/31199
+pytestmark = pytest.mark.skip_with_pyarrow_strings  # no support for hdf yet
+
 
 def test_to_hdf():
     pytest.importorskip("tables")
@@ -46,6 +52,10 @@ def test_to_hdf():
         tm.assert_frame_equal(df, out[:])
 
 
+@pytest.mark.skipif(
+    PY_VERSION >= Version("3.11"),
+    reason="segfaults due to https://github.com/PyTables/PyTables/issues/977",
+)
 def test_to_hdf_multiple_nodes():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -388,6 +398,10 @@ def test_to_hdf_link_optimizations():
         assert dependency_depth(d.dask) == 2 + a.npartitions
 
 
+@pytest.mark.skipif(
+    PY_VERSION >= Version("3.11"),
+    reason="segfaults due to https://github.com/PyTables/PyTables/issues/977",
+)
 @pytest.mark.slow
 def test_to_hdf_lock_delays():
     pytest.importorskip("tables")
@@ -478,6 +492,10 @@ def test_to_hdf_exceptions():
                 a.to_hdf(hdf, "/data_*_*")
 
 
+@pytest.mark.skipif(
+    PY_VERSION >= Version("3.11"),
+    reason="segfaults due to https://github.com/PyTables/PyTables/issues/977",
+)
 @pytest.mark.parametrize("scheduler", ["sync", "threads", "processes"])
 @pytest.mark.parametrize("npartitions", [1, 4, 10])
 def test_to_hdf_schedulers(scheduler, npartitions):
@@ -679,6 +697,10 @@ def test_read_hdf_multiply_open():
             dd.read_hdf(fn, "/data", chunksize=2, mode="r")
 
 
+@pytest.mark.skipif(
+    PY_VERSION >= Version("3.11"),
+    reason="segfaults due to https://github.com/PyTables/PyTables/issues/977",
+)
 def test_read_hdf_multiple():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -854,7 +876,6 @@ def test_hdf_filenames():
 
 
 def test_hdf_path_exceptions():
-
     # single file doesn't exist
     with pytest.raises(IOError):
         dd.read_hdf("nonexistant_store_X34HJK", "/tmp")
@@ -910,12 +931,12 @@ def test_hdf_nonpandas_keys():
         dd.read_hdf(path, "/bar")
 
 
-def test_hdf_empty_dataframe():
+def test_hdf_empty_dataframe(tmp_path):
     pytest.importorskip("tables")
     # https://github.com/dask/dask/issues/8707
     from dask.dataframe.io.hdf import dont_use_fixed_error_message
 
     df = pd.DataFrame({"A": [], "B": []}, index=[])
-    df.to_hdf("data.h5", format="fixed", key="df", mode="w")
+    df.to_hdf(tmp_path / "data.h5", format="fixed", key="df", mode="w")
     with pytest.raises(TypeError, match=dont_use_fixed_error_message):
-        dd.read_hdf("data.h5", "df")
+        dd.read_hdf(tmp_path / "data.h5", "df")
