@@ -10,6 +10,7 @@ from dask.array.core import normalize_arg
 from dask.base import tokenize
 from dask.blockwise import BlockwiseDepDict
 from dask.dataframe import methods
+from dask.dataframe._compat import check_axis_keyword_deprecation
 from dask.dataframe.core import (
     Scalar,
     _Frame,
@@ -21,8 +22,14 @@ from dask.dataframe.core import (
     no_default,
     partitionwise_graph,
 )
+from dask.dataframe.io import from_pandas
 from dask.dataframe.multi import _maybe_align_partitions
-from dask.dataframe.utils import insert_meta_param_description
+from dask.dataframe.utils import (
+    insert_meta_param_description,
+    is_dask_collection,
+    is_dataframe_like,
+    is_series_like,
+)
 from dask.delayed import unpack_collections
 from dask.highlevelgraph import HighLevelGraph
 from dask.utils import M, apply, derived_from, funcname, has_keyword
@@ -147,9 +154,14 @@ def map_overlap(
     --------
     dd.DataFrame.map_overlap
     """
-    args = (df,) + args
 
-    dfs = [df for df in args if isinstance(df, _Frame)]
+    df = (
+        from_pandas(df, 1)
+        if (is_series_like(df) or is_dataframe_like(df)) and not is_dask_collection(df)
+        else df
+    )
+
+    args = (df,) + args
 
     if isinstance(before, str):
         before = pd.to_timedelta(before)
@@ -157,7 +169,7 @@ def map_overlap(
         after = pd.to_timedelta(after)
 
     if isinstance(before, datetime.timedelta) or isinstance(after, datetime.timedelta):
-        if not is_datetime64_any_dtype(dfs[0].index._meta_nonempty.inferred_type):
+        if not is_datetime64_any_dtype(df.index._meta_nonempty.inferred_type):
             raise TypeError(
                 "Must have a `DatetimeIndex` when using string offset "
                 "for `before` and `after`"
@@ -192,6 +204,8 @@ def map_overlap(
                 "calling `map_overlap` directly, pass `align_dataframes=False`."
             ) from e
 
+    dfs = [df for df in args if isinstance(df, _Frame)]
+
     meta = _get_meta_map_partitions(args, dfs, func, kwargs, meta, parent_meta)
 
     if all(isinstance(arg, Scalar) for arg in args):
@@ -344,7 +358,6 @@ def _get_previous_partitions(df, before):
 
     name_a = "overlap-prepend-" + tokenize(df, before)
     if before and isinstance(before, Integral):
-
         prevs = [None]
         for i in range(df.npartitions - 1):
             key = (name_a, i)
@@ -442,7 +455,13 @@ class Rolling:
     """Provides rolling window calculations."""
 
     def __init__(
-        self, obj, window=None, min_periods=None, center=False, win_type=None, axis=0
+        self,
+        obj,
+        window=None,
+        min_periods=None,
+        center=False,
+        win_type=None,
+        axis=no_default,
     ):
         self.obj = obj  # dataframe or series
         self.window = window
@@ -460,13 +479,15 @@ class Rolling:
         self._win_type = None if isinstance(self.window, int) else "freq"
 
     def _rolling_kwargs(self):
-        return {
+        kwargs = {
             "window": self.window,
             "min_periods": self.min_periods,
             "center": self.center,
             "win_type": self.win_type,
-            "axis": self.axis,
         }
+        if self.axis is not no_default:
+            kwargs["axis"] = self.axis
+        return kwargs
 
     @property
     def _has_single_partition(self):
@@ -482,7 +503,8 @@ class Rolling:
 
     @staticmethod
     def pandas_rolling_method(df, rolling_kwargs, name, *args, **kwargs):
-        rolling = df.rolling(**rolling_kwargs)
+        with check_axis_keyword_deprecation():
+            rolling = df.rolling(**rolling_kwargs)
         return getattr(rolling, name)(*args, **kwargs)
 
     def _call_method(self, method_name, *args, **kwargs):
@@ -599,10 +621,8 @@ class Rolling:
         )
 
     @derived_from(pd_Rolling)
-    def aggregate(self, func, args=(), kwargs=None, **kwds):
-        if kwargs is None:
-            kwargs = {}
-        return self._call_method("agg", func, args=args, kwargs=kwargs, **kwds)
+    def aggregate(self, func, *args, **kwargs):
+        return self._call_method("agg", func, *args, **kwargs)
 
     agg = aggregate
 
@@ -664,6 +684,13 @@ class RollingGroupby(Rolling):
             axis=axis,
         )
 
+    def _rolling_kwargs(self):
+        kwargs = super()._rolling_kwargs()
+        if kwargs.get("axis", None) in (0, "index"):
+            # it's a default, no need to pass
+            kwargs.pop("axis")
+        return kwargs
+
     @staticmethod
     def pandas_rolling_method(
         df,
