@@ -1,10 +1,14 @@
-import pandas as pd
+# flake8: noqa: W291
 from textwrap import dedent
 
-import dask.dataframe as dd
-import dask.array as da
 import numpy as np
+import pandas as pd
+import pytest
 
+import dask.array as da
+import dask.dataframe as dd
+from dask.dataframe.utils import get_string_dtype, pyarrow_strings_enabled
+from dask.utils import maybe_pluralize
 
 style = """<style scoped>
     .dataframe tbody tr th:only-of-type {
@@ -22,6 +26,16 @@ style = """<style scoped>
 """
 
 
+def _format_string_dtype():
+    return "object" if get_string_dtype() is object else "string"
+
+
+def _format_footer(suffix="", layers=1):
+    if pyarrow_strings_enabled():
+        return f"Dask Name: to_pyarrow_string{suffix}, {maybe_pluralize(layers + 1, 'graph layer')}"
+    return f"Dask Name: from_pandas{suffix}, {maybe_pluralize(layers, 'graph layer')}"
+
+
 def test_repr():
     df = pd.DataFrame({"x": list(range(100))})
     ddf = dd.from_pandas(df, 3)
@@ -42,6 +56,7 @@ def test_repr_meta_mutation():
 
 
 def test_dataframe_format():
+    pytest.importorskip("jinja2")
     df = pd.DataFrame(
         {
             "A": [1, 2, 3, 4, 5, 6, 7, 8],
@@ -50,30 +65,35 @@ def test_dataframe_format():
         }
     )
     ddf = dd.from_pandas(df, 3)
-    exp = (
-        "Dask DataFrame Structure:\n"
-        "                   A       B                C\n"
-        "npartitions=3                                \n"
-        "0              int64  object  category[known]\n"
-        "3                ...     ...              ...\n"
-        "6                ...     ...              ...\n"
-        "7                ...     ...              ...\n"
-        "Dask Name: from_pandas, 3 tasks"
+    string_dtype = _format_string_dtype()
+    footer = _format_footer()
+    exp = dedent(
+        f"""\
+        Dask DataFrame Structure:
+                           A       B                C
+        npartitions=3                                
+        0              int64  {string_dtype}  category[known]
+        3                ...     ...              ...
+        6                ...     ...              ...
+        7                ...     ...              ...
+        {footer}"""
     )
+
     assert repr(ddf) == exp
     assert str(ddf) == exp
 
-    exp = (
-        "                   A       B                C\n"
-        "npartitions=3                                \n"
-        "0              int64  object  category[known]\n"
-        "3                ...     ...              ...\n"
-        "6                ...     ...              ...\n"
-        "7                ...     ...              ..."
+    exp = dedent(
+        f"""\
+                           A       B                C
+        npartitions=3                                
+        0              int64  {string_dtype}  category[known]
+        3                ...     ...              ...
+        6                ...     ...              ...
+        7                ...     ...              ..."""
     )
     assert ddf.to_string() == exp
 
-    exp_table = """<table border="1" class="dataframe">
+    exp_table = f"""<table border="1" class="dataframe">
   <thead>
     <tr style="text-align: right;">
       <th></th>
@@ -92,7 +112,7 @@ def test_dataframe_format():
     <tr>
       <th>0</th>
       <td>int64</td>
-      <td>object</td>
+      <td>{string_dtype}</td>
       <td>category[known]</td>
     </tr>
     <tr>
@@ -116,25 +136,22 @@ def test_dataframe_format():
   </tbody>
 </table>"""
 
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 {exp_table}
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf.to_html() == exp
 
     # table is boxed with div and has style
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 <div>
 {style}{exp_table}
 </div>
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        style=style, exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf._repr_html_() == exp
 
 
 def test_dataframe_format_with_index():
+    pytest.importorskip("jinja2")
     df = pd.DataFrame(
         {
             "A": [1, 2, 3, 4, 5, 6, 7, 8],
@@ -144,20 +161,23 @@ def test_dataframe_format_with_index():
         index=list("ABCDEFGH"),
     )
     ddf = dd.from_pandas(df, 3)
-    exp = (
-        "Dask DataFrame Structure:\n"
-        "                   A       B                C\n"
-        "npartitions=3                                \n"
-        "A              int64  object  category[known]\n"
-        "D                ...     ...              ...\n"
-        "G                ...     ...              ...\n"
-        "H                ...     ...              ...\n"
-        "Dask Name: from_pandas, 3 tasks"
+    string_dtype = _format_string_dtype()
+    footer = _format_footer()
+    exp = dedent(
+        f"""\
+        Dask DataFrame Structure:
+                           A       B                C
+        npartitions=3                                
+        A              int64  {string_dtype}  category[known]
+        D                ...     ...              ...
+        G                ...     ...              ...
+        H                ...     ...              ...
+        {footer}"""
     )
     assert repr(ddf) == exp
     assert str(ddf) == exp
 
-    exp_table = """<table border="1" class="dataframe">
+    exp_table = f"""<table border="1" class="dataframe">
   <thead>
     <tr style="text-align: right;">
       <th></th>
@@ -176,7 +196,7 @@ def test_dataframe_format_with_index():
     <tr>
       <th>A</th>
       <td>int64</td>
-      <td>object</td>
+      <td>{string_dtype}</td>
       <td>category[known]</td>
     </tr>
     <tr>
@@ -200,25 +220,22 @@ def test_dataframe_format_with_index():
   </tbody>
 </table>"""
 
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 {exp_table}
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf.to_html() == exp
 
     # table is boxed with div and has style
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 <div>
 {style}{exp_table}
 </div>
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        style=style, exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf._repr_html_() == exp
 
 
 def test_dataframe_format_unknown_divisions():
+    pytest.importorskip("jinja2")
     df = pd.DataFrame(
         {
             "A": [1, 2, 3, 4, 5, 6, 7, 8],
@@ -230,30 +247,35 @@ def test_dataframe_format_unknown_divisions():
     ddf = ddf.clear_divisions()
     assert not ddf.known_divisions
 
-    exp = (
-        "Dask DataFrame Structure:\n"
-        "                   A       B                C\n"
-        "npartitions=3                                \n"
-        "               int64  object  category[known]\n"
-        "                 ...     ...              ...\n"
-        "                 ...     ...              ...\n"
-        "                 ...     ...              ...\n"
-        "Dask Name: from_pandas, 3 tasks"
+    string_dtype = _format_string_dtype()
+    footer = _format_footer()
+
+    exp = dedent(
+        f"""\
+        Dask DataFrame Structure:
+                           A       B                C
+        npartitions=3                                
+                       int64  {string_dtype}  category[known]
+                         ...     ...              ...
+                         ...     ...              ...
+                         ...     ...              ...
+        {footer}"""
     )
     assert repr(ddf) == exp
     assert str(ddf) == exp
 
-    exp = (
-        "                   A       B                C\n"
-        "npartitions=3                                \n"
-        "               int64  object  category[known]\n"
-        "                 ...     ...              ...\n"
-        "                 ...     ...              ...\n"
-        "                 ...     ...              ..."
+    exp = dedent(
+        f"""\
+                           A       B                C
+        npartitions=3                                
+                       int64  {string_dtype}  category[known]
+                         ...     ...              ...
+                         ...     ...              ...
+                         ...     ...              ..."""
     )
     assert ddf.to_string() == exp
 
-    exp_table = """<table border="1" class="dataframe">
+    exp_table = f"""<table border="1" class="dataframe">
   <thead>
     <tr style="text-align: right;">
       <th></th>
@@ -272,7 +294,7 @@ def test_dataframe_format_unknown_divisions():
     <tr>
       <th></th>
       <td>int64</td>
-      <td>object</td>
+      <td>{string_dtype}</td>
       <td>category[known]</td>
     </tr>
     <tr>
@@ -296,25 +318,22 @@ def test_dataframe_format_unknown_divisions():
   </tbody>
 </table>"""
 
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 {exp_table}
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf.to_html() == exp
 
     # table is boxed with div and has style
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 <div>
 {style}{exp_table}
 </div>
-<div>Dask Name: from_pandas, 3 tasks</div>""".format(
-        style=style, exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf._repr_html_() == exp
 
 
 def test_dataframe_format_long():
+    pytest.importorskip("jinja2")
     df = pd.DataFrame(
         {
             "A": [1, 2, 3, 4, 5, 6, 7, 8] * 10,
@@ -322,33 +341,37 @@ def test_dataframe_format_long():
             "C": pd.Categorical(list("AAABBBCC") * 10),
         }
     )
+    string_dtype = _format_string_dtype()
+    footer = _format_footer()
     ddf = dd.from_pandas(df, 10)
-    exp = (
-        "Dask DataFrame Structure:\n"
-        "                    A       B                C\n"
-        "npartitions=10                                \n"
-        "0               int64  object  category[known]\n"
-        "8                 ...     ...              ...\n"
-        "...               ...     ...              ...\n"
-        "72                ...     ...              ...\n"
-        "79                ...     ...              ...\n"
-        "Dask Name: from_pandas, 10 tasks"
+    exp = dedent(
+        f"""\
+        Dask DataFrame Structure:
+                            A       B                C
+        npartitions=10                                
+        0               int64  {string_dtype}  category[known]
+        8                 ...     ...              ...
+        ...               ...     ...              ...
+        72                ...     ...              ...
+        79                ...     ...              ...
+        {footer}"""
     )
     assert repr(ddf) == exp
     assert str(ddf) == exp
 
-    exp = (
-        "                    A       B                C\n"
-        "npartitions=10                                \n"
-        "0               int64  object  category[known]\n"
-        "8                 ...     ...              ...\n"
-        "...               ...     ...              ...\n"
-        "72                ...     ...              ...\n"
-        "79                ...     ...              ..."
+    exp = dedent(
+        f"""\
+                            A       B                C
+        npartitions=10                                
+        0               int64  {string_dtype}  category[known]
+        8                 ...     ...              ...
+        ...               ...     ...              ...
+        72                ...     ...              ...
+        79                ...     ...              ..."""
     )
     assert ddf.to_string() == exp
 
-    exp_table = """<table border="1" class="dataframe">
+    exp_table = f"""<table border="1" class="dataframe">
   <thead>
     <tr style="text-align: right;">
       <th></th>
@@ -367,7 +390,7 @@ def test_dataframe_format_long():
     <tr>
       <th>0</th>
       <td>int64</td>
-      <td>object</td>
+      <td>{string_dtype}</td>
       <td>category[known]</td>
     </tr>
     <tr>
@@ -397,55 +420,61 @@ def test_dataframe_format_long():
   </tbody>
 </table>"""
 
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 {exp_table}
-<div>Dask Name: from_pandas, 10 tasks</div>""".format(
-        exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf.to_html() == exp
 
     # table is boxed with div
-    exp = """<div><strong>Dask DataFrame Structure:</strong></div>
+    exp = f"""<div><strong>Dask DataFrame Structure:</strong></div>
 <div>
 {style}{exp_table}
 </div>
-<div>Dask Name: from_pandas, 10 tasks</div>""".format(
-        style=style, exp_table=exp_table
-    )
+<div>{footer}</div>"""
     assert ddf._repr_html_() == exp
 
 
 def test_series_format():
     s = pd.Series([1, 2, 3, 4, 5, 6, 7, 8], index=list("ABCDEFGH"))
     ds = dd.from_pandas(s, 3)
-    exp = """Dask Series Structure:
-npartitions=3
-A    int64
-D      ...
-G      ...
-H      ...
-dtype: int64
-Dask Name: from_pandas, 3 tasks"""
+    footer = _format_footer()
+    exp = dedent(
+        f"""\
+    Dask Series Structure:
+    npartitions=3
+    A    int64
+    D      ...
+    G      ...
+    H      ...
+    dtype: int64
+    {footer}"""
+    )
     assert repr(ds) == exp
     assert str(ds) == exp
 
-    exp = """npartitions=3
-A    int64
-D      ...
-G      ...
-H      ..."""
+    exp = dedent(
+        """\
+    npartitions=3
+    A    int64
+    D      ...
+    G      ...
+    H      ..."""
+    )
     assert ds.to_string() == exp
 
     s = pd.Series([1, 2, 3, 4, 5, 6, 7, 8], index=list("ABCDEFGH"), name="XXX")
     ds = dd.from_pandas(s, 3)
-    exp = """Dask Series Structure:
-npartitions=3
-A    int64
-D      ...
-G      ...
-H      ...
-Name: XXX, dtype: int64
-Dask Name: from_pandas, 3 tasks"""
+    exp = dedent(
+        f"""\
+    Dask Series Structure:
+    npartitions=3
+    A    int64
+    D      ...
+    G      ...
+    H      ...
+    Name: XXX, dtype: int64
+    {footer}"""
+    )
     assert repr(ds) == exp
     assert str(ds) == exp
 
@@ -453,29 +482,49 @@ Dask Name: from_pandas, 3 tasks"""
 def test_series_format_long():
     s = pd.Series([1, 2, 3, 4, 5, 6, 7, 8, 9, 10] * 10, index=list("ABCDEFGHIJ") * 10)
     ds = dd.from_pandas(s, 10)
-    exp = (
-        "Dask Series Structure:\nnpartitions=10\nA    int64\nB      ...\n"
-        "     ...  \nJ      ...\nJ      ...\ndtype: int64\n"
-        "Dask Name: from_pandas, 10 tasks"
+    footer = _format_footer()
+    exp = dedent(
+        f"""\
+        Dask Series Structure:
+        npartitions=10
+        A    int64
+        B      ...
+             ...  
+        J      ...
+        J      ...
+        dtype: int64
+        {footer}"""
     )
     assert repr(ds) == exp
     assert str(ds) == exp
-
-    exp = "npartitions=10\nA    int64\nB      ...\n     ...  \nJ      ...\nJ      ..."
+    exp = dedent(
+        """\
+    npartitions=10
+    A    int64
+    B      ...
+         ...  
+    J      ...
+    J      ..."""
+    )
     assert ds.to_string() == exp
 
 
 def test_index_format():
     s = pd.Series([1, 2, 3, 4, 5, 6, 7, 8], index=list("ABCDEFGH"))
     ds = dd.from_pandas(s, 3)
-    exp = """Dask Index Structure:
-npartitions=3
-A    object
-D       ...
-G       ...
-H       ...
-dtype: object
-Dask Name: from_pandas, 6 tasks"""
+    string_dtype = _format_string_dtype()
+    footer = _format_footer("-index", 2)
+    exp = dedent(
+        f"""\
+    Dask Index Structure:
+    npartitions=3
+    A    {string_dtype}
+    D       ...
+    G       ...
+    H       ...
+    dtype: {string_dtype}
+    {footer}"""
+    )
     assert repr(ds.index) == exp
     assert str(ds.index) == exp
 
@@ -493,7 +542,7 @@ Dask Name: from_pandas, 6 tasks"""
     7                ...
     8                ...
     Name: YYY, dtype: category
-    Dask Name: from_pandas, 6 tasks"""
+    Dask Name: from_pandas-index, 2 graph layers"""
     )
     assert repr(ds.index) == exp
     assert str(ds.index) == exp
@@ -509,7 +558,7 @@ def test_categorical_format():
         "0    category[known]\n"
         "2                ...\n"
         "dtype: category\n"
-        "Dask Name: from_pandas, 1 tasks"
+        "Dask Name: from_pandas, 1 graph layer"
     )
     assert repr(known) == exp
     exp = (
@@ -518,7 +567,7 @@ def test_categorical_format():
         "0    category[unknown]\n"
         "2                  ...\n"
         "dtype: category\n"
-        "Dask Name: from_pandas, 1 tasks"
+        "Dask Name: from_pandas, 1 graph layer"
     )
     assert repr(unknown) == exp
 
@@ -530,13 +579,14 @@ def test_duplicate_columns_repr():
 
 
 def test_empty_repr():
+    pytest.importorskip("jinja2")
     df = pd.DataFrame()
     ddf = dd.from_pandas(df, npartitions=1)
     exp = (
         "Empty Dask DataFrame Structure:\n"
         "Columns: []\n"
         "Divisions: [, ]\n"
-        "Dask Name: from_pandas, 1 tasks"
+        "Dask Name: from_pandas, 1 graph layer"
     )
     assert repr(ddf) == exp
     exp_table = """<table border="1" class="dataframe">
@@ -561,7 +611,7 @@ def test_empty_repr():
 <div>
 {style}{exp_table}
 </div>
-<div>Dask Name: from_pandas, 1 tasks</div>""".format(
+<div>Dask Name: from_pandas, 1 graph layer</div>""".format(
         style=style, exp_table=exp_table
     )
     assert ddf._repr_html_() == exp
