@@ -4,13 +4,8 @@ import pandas as pd
 import pytest
 
 import dask.dataframe as dd
-from dask.dataframe.tseries.resample import getnanos
 from dask.dataframe.utils import assert_eq
 
-CHECK_FREQ = {}
-if dd._compat.PANDAS_GT_110:
-    CHECK_FREQ["check_freq"] = False
-
 
 def resample(df, freq, how="mean", **kwargs):
     return getattr(df.resample(freq, **kwargs), how)()
@@ -199,7 +194,7 @@ def test_series_resample_non_existent_datetime():
     result = ddf.resample("1D").mean()
     expected = df.resample("1D").mean()
 
-    assert_eq(result, expected, **CHECK_FREQ)
+    assert_eq(result, expected, check_freq=False)
 
 
 @pytest.mark.parametrize("agg", ["nunique", "mean", "count", "size", "quantile"])
@@ -214,8 +209,3 @@ def test_common_aggs(agg):
     expected = f(ds.resample("1d"))
 
     assert_eq(res, expected, check_dtype=False)
-
-
-def test_getnanos_deprecated():
-    with pytest.warns(FutureWarning, match="getnanos was deprecated"):
-        getnanos(None)
