@@ -4,6 +4,7 @@ import functools
 import math
 import operator
 from collections import defaultdict
+from collections.abc import Callable
 from itertools import product
 from typing import Any
 
@@ -12,16 +13,9 @@ from tlz.curried import map
 
 from dask.base import tokenize
 from dask.blockwise import Blockwise, BlockwiseDep, BlockwiseDepDict, blockwise_token
-from dask.core import flatten, keys_in_tasks
+from dask.core import flatten
 from dask.highlevelgraph import Layer
-from dask.utils import (
-    apply,
-    cached_cumsum,
-    concrete,
-    insert,
-    stringify,
-    stringify_collection_keys,
-)
+from dask.utils import apply, cached_cumsum, concrete, insert
 
 #
 ##
@@ -71,15 +65,6 @@ class ArrayBlockwiseDep(BlockwiseDep):
     def __getitem__(self, idx: tuple[int, ...]):
         raise NotImplementedError("Subclasses must implement __getitem__")
 
-    def __dask_distributed_pack__(
-        self, required_indices: list[tuple[int, ...]] | None = None
-    ):
-        return {"chunks": self.chunks}
-
-    @classmethod
-    def __dask_distributed_unpack__(cls, state):
-        return cls(**state)
-
 
 class ArrayChunkShapeDep(ArrayBlockwiseDep):
     """Produce chunk shapes given a chunk index"""
@@ -223,10 +208,6 @@ class ArrayOverlapLayer(Layer):
         dsk = toolz.merge(interior_slices, overlap_blocks)
         return dsk
 
-    @classmethod
-    def __dask_distributed_unpack__(cls, state):
-        return cls(**state)._construct_graph(deserializing=True)
-
 
 def _expand_keys_around_center(k, dims, name=None, axes=None):
     """Get all neighboring keys around center
@@ -384,7 +365,6 @@ class SimpleShuffleLayer(Layer):
         parts_out=None,
         annotations=None,
     ):
-        super().__init__(annotations=annotations)
         self.name = name
         self.column = column
         self.npartitions = npartitions
@@ -401,26 +381,26 @@ class SimpleShuffleLayer(Layer):
         # depth-first delays the freeing of the result of `shuffle_group()`
         # until the end of the shuffling.
         #
-        # We address this by manually setting a high "prioroty" to the
+        # We address this by manually setting a high "priority" to the
         # `getitem()` ("split") tasks, using annotations. This forces a
-        # breadth-first scheduling of the tasks tath directly depend on
+        # breadth-first scheduling of the tasks that directly depend on
         # the `shuffle_group()` output, allowing that data to be freed
         # much earlier.
         #
         # See https://github.com/dask/dask/pull/6051 for a detailed discussion.
-        self.annotations = self.annotations or {}
-        if "priority" not in self.annotations:
-            self.annotations["priority"] = {}
-        self.annotations["priority"]["__expanded_annotations__"] = None
-        self.annotations["priority"].update({_key: 1 for _key in self.get_split_keys()})
+        annotations = annotations or {}
+        self._split_keys = None
+        if "priority" not in annotations:
+            annotations["priority"] = self._key_priority
 
-    def get_split_keys(self):
-        # Return SimpleShuffleLayer "split" keys
-        return [
-            stringify((self.split_name, part_out, part_in))
-            for part_in in range(self.npartitions_input)
-            for part_out in self.parts_out
-        ]
+        super().__init__(annotations=annotations)
+
+    def _key_priority(self, key):
+        assert isinstance(key, tuple)
+        if key[0] == self.split_name:
+            return 1
+        else:
+            return 0
 
     def get_output_keys(self):
         return {(self.name, part) for part in self.parts_out}
@@ -496,7 +476,7 @@ class SimpleShuffleLayer(Layer):
         """Cull a SimpleShuffleLayer HighLevelGraph layer.
 
         The underlying graph will only include the necessary
-        tasks to produce the keys (indicies) included in `parts_out`.
+        tasks to produce the keys (indices) included in `parts_out`.
         Therefore, "culling" the layer only requires us to reset this
         parameter.
         """
@@ -508,61 +488,6 @@ class SimpleShuffleLayer(Layer):
         else:
             return self, culled_deps
 
-    def __reduce__(self):
-        attrs = [
-            "name",
-            "column",
-            "npartitions",
-            "npartitions_input",
-            "ignore_index",
-            "name_input",
-            "meta_input",
-            "parts_out",
-            "annotations",
-        ]
-        return (SimpleShuffleLayer, tuple(getattr(self, attr) for attr in attrs))
-
-    def __dask_distributed_pack__(
-        self, all_hlg_keys, known_key_dependencies, client, client_keys
-    ):
-        from distributed.protocol.serialize import to_serialize
-
-        return {
-            "name": self.name,
-            "column": self.column,
-            "npartitions": self.npartitions,
-            "npartitions_input": self.npartitions_input,
-            "ignore_index": self.ignore_index,
-            "name_input": self.name_input,
-            "meta_input": to_serialize(self.meta_input),
-            "parts_out": list(self.parts_out),
-        }
-
-    @classmethod
-    def __dask_distributed_unpack__(cls, state, dsk, dependencies):
-        from distributed.worker import dumps_task
-
-        # msgpack will convert lists into tuples, here
-        # we convert them back to lists
-        if isinstance(state["column"], tuple):
-            state["column"] = list(state["column"])
-        if "inputs" in state:
-            state["inputs"] = list(state["inputs"])
-
-        # Materialize the layer
-        layer_dsk = cls(**state)._construct_graph(deserializing=True)
-
-        # Convert all keys to strings and dump tasks
-        layer_dsk = {
-            stringify(k): stringify_collection_keys(v) for k, v in layer_dsk.items()
-        }
-        keys = layer_dsk.keys() | dsk.keys()
-
-        # TODO: use shuffle-knowledge to calculate dependencies more efficiently
-        deps = {k: keys_in_tasks(keys, [v]) for k, v in layer_dsk.items()}
-
-        return {"dsk": toolz.valmap(dumps_task, layer_dsk), "deps": deps}
-
     def _construct_graph(self, deserializing=False):
         """Construct graph for a simple shuffle operation."""
 
@@ -679,53 +604,11 @@ class ShuffleLayer(SimpleShuffleLayer):
             annotations=annotations,
         )
 
-    def get_split_keys(self):
-        # Return ShuffleLayer "split" keys
-        keys = []
-        for part in self.parts_out:
-            out = self.inputs[part]
-            for i in range(self.nsplits):
-                keys.append(
-                    stringify(
-                        (
-                            self.split_name,
-                            out[self.stage],
-                            insert(out, self.stage, i),
-                        )
-                    )
-                )
-        return keys
-
     def __repr__(self):
         return "ShuffleLayer<name='{}', stage={}, nsplits={}, npartitions={}>".format(
             self.name, self.stage, self.nsplits, self.npartitions
         )
 
-    def __reduce__(self):
-        attrs = [
-            "name",
-            "column",
-            "inputs",
-            "stage",
-            "npartitions",
-            "npartitions_input",
-            "nsplits",
-            "ignore_index",
-            "name_input",
-            "meta_input",
-            "parts_out",
-            "annotations",
-        ]
-
-        return (ShuffleLayer, tuple(getattr(self, attr) for attr in attrs))
-
-    def __dask_distributed_pack__(self, *args, **kwargs):
-        ret = super().__dask_distributed_pack__(*args, **kwargs)
-        ret["inputs"] = self.inputs
-        ret["stage"] = self.stage
-        ret["nsplits"] = self.nsplits
-        return ret
-
     def _cull_dependencies(self, keys, parts_out=None):
         """Determine the necessary dependencies to produce `keys`.
 
@@ -780,7 +663,6 @@ class ShuffleLayer(SimpleShuffleLayer):
         dsk = {}
         inp_part_map = {inp: i for i, inp in enumerate(self.inputs)}
         for part in self.parts_out:
-
             out = self.inputs[part]
 
             _concat_list = []  # get_item tasks to concat for this output partition
@@ -805,7 +687,6 @@ class ShuffleLayer(SimpleShuffleLayer):
                 )
 
                 if (shuffle_group_name, _inp) not in dsk:
-
                     # Initial partitions (output of previous stage)
                     _part = inp_part_map[_inp]
                     if self.stage == 0:
@@ -871,6 +752,8 @@ class BroadcastJoinLayer(Layer):
         rhs_npartitions,
         parts_out=None,
         annotations=None,
+        left_on=None,
+        right_on=None,
         **merge_kwargs,
     ):
         super().__init__(annotations=annotations)
@@ -881,14 +764,12 @@ class BroadcastJoinLayer(Layer):
         self.rhs_name = rhs_name
         self.rhs_npartitions = rhs_npartitions
         self.parts_out = parts_out or set(range(self.npartitions))
+        self.left_on = tuple(left_on) if isinstance(left_on, list) else left_on
+        self.right_on = tuple(right_on) if isinstance(right_on, list) else right_on
         self.merge_kwargs = merge_kwargs
         self.how = self.merge_kwargs.get("how")
-        self.left_on = self.merge_kwargs.get("left_on")
-        self.right_on = self.merge_kwargs.get("right_on")
-        if isinstance(self.left_on, list):
-            self.left_on = (list, tuple(self.left_on))
-        if isinstance(self.right_on, list):
-            self.right_on = (list, tuple(self.right_on))
+        self.merge_kwargs["left_on"] = self.left_on
+        self.merge_kwargs["right_on"] = self.right_on
 
     def get_output_keys(self):
         return {(self.name, part) for part in self.parts_out}
@@ -920,47 +801,6 @@ class BroadcastJoinLayer(Layer):
     def __len__(self):
         return len(self._dict)
 
-    def __dask_distributed_pack__(self, *args, **kwargs):
-        import pickle
-
-        # Pickle complex merge_kwargs elements. Also
-        # tuples, which may be confused with keys.
-        _merge_kwargs = {}
-        for k, v in self.merge_kwargs.items():
-            if not isinstance(v, (str, list, bool)):
-                _merge_kwargs[k] = pickle.dumps(v)
-            else:
-                _merge_kwargs[k] = v
-
-        return {
-            "name": self.name,
-            "npartitions": self.npartitions,
-            "lhs_name": self.lhs_name,
-            "lhs_npartitions": self.lhs_npartitions,
-            "rhs_name": self.rhs_name,
-            "rhs_npartitions": self.rhs_npartitions,
-            "parts_out": self.parts_out,
-            "merge_kwargs": _merge_kwargs,
-        }
-
-    @classmethod
-    def __dask_distributed_unpack__(cls, state, dsk, dependencies):
-        from distributed.worker import dumps_task
-
-        # Expand merge_kwargs
-        merge_kwargs = state.pop("merge_kwargs", {})
-        state.update(merge_kwargs)
-
-        # Materialize the layer
-        raw = cls(**state)._construct_graph(deserializing=True)
-
-        # Convert all keys to strings and dump tasks
-        raw = {stringify(k): stringify_collection_keys(v) for k, v in raw.items()}
-        keys = raw.keys() | dsk.keys()
-        deps = {k: keys_in_tasks(keys, [v]) for k, v in raw.items()}
-
-        return {"dsk": toolz.valmap(dumps_task, raw), "deps": deps}
-
     def _keys_to_parts(self, keys):
         """Simple utility to convert keys to partition indices."""
         parts = set()
@@ -1005,7 +845,7 @@ class BroadcastJoinLayer(Layer):
 
         For a broadcast join, output partitions always depend on
         all partitions of the broadcasted collection, but only one
-        partition of the "other" collecction.
+        partition of the "other" collection.
         """
         # Get broadcast info
         bcast_name, bcast_size, other_name = self._broadcast_plan[:3]
@@ -1036,7 +876,7 @@ class BroadcastJoinLayer(Layer):
         """Cull a BroadcastJoinLayer HighLevelGraph layer.
 
         The underlying graph will only include the necessary
-        tasks to produce the keys (indicies) included in `parts_out`.
+        tasks to produce the keys (indices) included in `parts_out`.
         Therefore, "culling" the layer only requires us to reset this
         parameter.
         """
@@ -1080,7 +920,6 @@ class BroadcastJoinLayer(Layer):
         # any output partitions that are not requested (via `parts_out`)
         dsk = {}
         for i in self.parts_out:
-
             # Split each "other" partition by hash
             if self.how != "inner":
                 dsk[(split_name, i)] = (
@@ -1138,7 +977,7 @@ class DataFrameIOLayer(Blockwise):
         Name to use for the constructed layer.
     columns : str, list or None
         Field name(s) to read in as columns in the output.
-    inputs : list[tuple]
+    inputs : list or BlockwiseDep
         List of arguments to be passed to ``io_func`` so
         that the materialized task to produce partition ``i``
         will be: ``(<io_func>, inputs[i])``.  Note that each
@@ -1146,6 +985,8 @@ class DataFrameIOLayer(Blockwise):
     io_func : callable
         A callable function that takes in a single tuple
         of arguments, and outputs a DataFrame partition.
+        Column projection will be supported for functions
+        that satisfy the ``DataFrameIOFunction`` protocol.
     label : str (optional)
         String to use as a prefix in the place-holder collection
         name. If nothing is specified (default), "subset-" will
@@ -1176,7 +1017,7 @@ class DataFrameIOLayer(Blockwise):
         annotations=None,
     ):
         self.name = name
-        self.columns = columns
+        self._columns = columns
         self.inputs = inputs
         self.io_func = io_func
         self.label = label
@@ -1184,11 +1025,14 @@ class DataFrameIOLayer(Blockwise):
         self.annotations = annotations
         self.creation_info = creation_info
 
-        # Define mapping between key index and "part"
-        io_arg_map = BlockwiseDepDict(
-            {(i,): inp for i, inp in enumerate(self.inputs)},
-            produces_tasks=self.produces_tasks,
-        )
+        if not isinstance(inputs, BlockwiseDep):
+            # Define mapping between key index and "part"
+            io_arg_map = BlockwiseDepDict(
+                {(i,): inp for i, inp in enumerate(self.inputs)},
+                produces_tasks=self.produces_tasks,
+            )
+        else:
+            io_arg_map = inputs
 
         # Use Blockwise initializer
         dsk = {self.name: (io_func, blockwise_token(0))}
@@ -1201,22 +1045,31 @@ class DataFrameIOLayer(Blockwise):
             annotations=annotations,
         )
 
+    @property
+    def columns(self):
+        """Current column projection for this layer"""
+        return self._columns
+
     def project_columns(self, columns):
         """Produce a column projection for this IO layer.
         Given a list of required output columns, this method
         returns the projected layer.
         """
-        if columns and (self.columns is None or columns < set(self.columns)):
+        from dask.dataframe.io.utils import DataFrameIOFunction
 
-            # Apply column projection in IO function
-            try:
-                io_func = self.io_func.project_columns(list(columns))
-            except AttributeError:
+        columns = list(columns)
+
+        if self.columns is None or set(self.columns).issuperset(columns):
+            # Apply column projection in IO function.
+            # Must satisfy `DataFrameIOFunction` protocol
+            if isinstance(self.io_func, DataFrameIOFunction):
+                io_func = self.io_func.project_columns(columns)
+            else:
                 io_func = self.io_func
 
             layer = DataFrameIOLayer(
-                (self.label or "subset-") + tokenize(self.name, columns),
-                list(columns),
+                (self.label or "subset") + "-" + tokenize(self.name, columns),
+                columns,
                 self.inputs,
                 io_func,
                 label=self.label,
@@ -1274,10 +1127,10 @@ class DataFrameTreeReduction(Layer):
 
     name: str
     name_input: str
-    npartitions_input: str
-    concat_func: callable
-    tree_node_func: callable
-    finalize_func: callable | None
+    npartitions_input: int
+    concat_func: Callable
+    tree_node_func: Callable
+    finalize_func: Callable | None
     split_every: int
     split_out: int
     output_partitions: list[int]
@@ -1289,10 +1142,10 @@ class DataFrameTreeReduction(Layer):
         self,
         name: str,
         name_input: str,
-        npartitions_input: str,
-        concat_func: callable,
-        tree_node_func: callable,
-        finalize_func: callable | None = None,
+        npartitions_input: int,
+        concat_func: Callable,
+        tree_node_func: Callable,
+        finalize_func: Callable | None = None,
         split_every: int = 32,
         split_out: int | None = None,
         output_partitions: list[int] | None = None,
@@ -1307,7 +1160,7 @@ class DataFrameTreeReduction(Layer):
         self.tree_node_func = tree_node_func
         self.finalize_func = finalize_func
         self.split_every = split_every
-        self.split_out = split_out
+        self.split_out = split_out  # type: ignore
         self.output_partitions = (
             list(range(self.split_out or 1))
             if output_partitions is None
@@ -1321,7 +1174,7 @@ class DataFrameTreeReduction(Layer):
         self.widths = [parts]
         while parts > 1:
             parts = math.ceil(parts / self.split_every)
-            self.widths.append(parts)
+            self.widths.append(int(parts))
         self.height = len(self.widths)
 
     def _make_key(self, *name_parts, split=0):
@@ -1496,49 +1349,3 @@ class DataFrameTreeReduction(Layer):
             return culled_layer, deps
         else:
             return self, deps
-
-    def __dask_distributed_pack__(self, *args, **kwargs):
-        from distributed.protocol.serialize import to_serialize
-
-        # Pickle the (possibly) user-defined functions here
-        _concat_func = to_serialize(self.concat_func)
-        _tree_node_func = to_serialize(self.tree_node_func)
-        if self.finalize_func:
-            _finalize_func = to_serialize(self.finalize_func)
-        else:
-            _finalize_func = None
-
-        return {
-            "name": self.name,
-            "name_input": self.name_input,
-            "npartitions_input": self.npartitions_input,
-            "concat_func": _concat_func,
-            "tree_node_func": _tree_node_func,
-            "finalize_func": _finalize_func,
-            "split_every": self.split_every,
-            "split_out": self.split_out,
-            "output_partitions": self.output_partitions,
-            "tree_node_name": self.tree_node_name,
-        }
-
-    @classmethod
-    def __dask_distributed_unpack__(cls, state, dsk, dependencies):
-        from distributed.protocol.serialize import to_serialize
-
-        # Materialize the layer
-        raw = cls(**state)._construct_graph()
-
-        # Convert all keys to strings and dump tasks
-        raw = {stringify(k): stringify_collection_keys(v) for k, v in raw.items()}
-        keys = raw.keys() | dsk.keys()
-        deps = {k: keys_in_tasks(keys, [v]) for k, v in raw.items()}
-
-        # Must use `to_serialize` on the entire task.
-        # This is required because the task-tuples contain `Serialized`
-        # function objects instead of real functions. Using `dumps_task`
-        # may or may not correctly wrap the entire tuple in `to_serialize`.
-        # So we use `to_serialize` here to be explicit. When the task
-        # arrives at a worker, both the `Serialized` task-tuples and the
-        # `Serialized` functions nested within them should be deserialzed
-        # automatically by the comm.
-        return {"dsk": toolz.valmap(to_serialize, raw), "deps": deps}
