@@ -1,10 +1,15 @@
 from pathlib import Path
 
+import pytest
+
 
 def test_development_guidelines_matches_ci():
     """When the environment.yaml changes in CI, make sure to change it in the docs as well"""
     root_dir = Path(__file__).parent.parent.parent
 
+    if not (root_dir / ".github" / "workflows").exists():
+        pytest.skip("Test can only be run on an editable install")
+
     development_doc_file = root_dir / "docs" / "source" / "develop.rst"
     additional_ci_file = root_dir / ".github" / "workflows" / "additional.yml"
     upstream_ci_file = root_dir / ".github" / "workflows" / "upstream.yml"
